RuntimePlugin

Trait RuntimePlugin 

pub trait RuntimePlugin:
    Debug
    + Send
    + Sync {
    // Provided methods
    fn order(&self) -> Order { ... }
    fn config(&self) -> Option<FrozenLayer> { ... }
    fn runtime_components(
        &self,
        current_components: &RuntimeComponentsBuilder,
    ) -> Cow<'_, RuntimeComponentsBuilder> { ... }
}
Runtime plugin trait

A RuntimePlugin is the unit of configuration for augmenting the client with new behavior.

Runtime plugins can register interceptors, set runtime components, and modify configuration.

Provided Methods

fn order(&self) -> Order

Runtime plugin ordering.

There are two runtime plugin “levels” that run in the following order:

  1. Service runtime plugins - runtime plugins that pertain to the entire service.
  2. Operation runtime plugins - runtime plugins relevant only to a single operation.

This function is used to determine runtime plugin order within those levels. So regardless of this Order value, service runtime plugins will still always execute before operation runtime plugins. However, Defaults service runtime plugins will run before Overrides service runtime plugins.

fn config(&self) -> Option<FrozenLayer>

Optionally returns additional config that should be added to the ConfigBag.

As a best practice, a frozen layer should be stored on the runtime plugin instance as a member, and then cloned upon return since that clone is cheap. Constructing a new Layer and freezing it will require a lot of allocations.

fn runtime_components( &self, current_components: &RuntimeComponentsBuilder, ) -> Cow<'_, RuntimeComponentsBuilder>

Returns a RuntimeComponentsBuilder to incorporate into the final runtime components.

The order of runtime plugins determines which runtime components “win”. Components set by later runtime plugins will override those set by earlier runtime plugins.

If no runtime component changes are desired, just return an empty builder.

This method returns a Cow for flexibility. Some implementers may want to store the components builder as a member and return a reference to it, while others may need to create the builder every call. If possible, returning a reference is preferred for performance.

Components configured by previous runtime plugins are in the current_components argument, and can be used to create nested/wrapped components, such as a connector calling into an inner (customer provided) connector.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl RuntimePlugin for CannedRequestSerializer

Source

impl RuntimePlugin for CannedResponseDeserializer

Source

impl RuntimePlugin for EnforceContentLengthRuntimePlugin

Source

impl RuntimePlugin for MetricsRuntimePlugin

Source

impl RuntimePlugin for NoAuthRuntimePluginV2

Source

impl RuntimePlugin for PayloadSigningOverrideRuntimePlugin

Implementors

Source

impl RuntimePlugin for CreateDeployment

Source

impl RuntimePlugin for CreateDeploymentSnapshot

Source

impl RuntimePlugin for CreatePolicy

Source

impl RuntimePlugin for CreatePolicySnapshot

Source

impl RuntimePlugin for CreateRule

Source

impl RuntimePlugin for CreateRuleSnapshot

Source

impl RuntimePlugin for CreateScope

Source

impl RuntimePlugin for CreateScopeSnapshot

Source

impl RuntimePlugin for CreateTemplate

Source

impl RuntimePlugin for CreateTemplateSnapshot

Source

impl RuntimePlugin for DeleteAdminAccount

Source

impl RuntimePlugin for DeleteDeployment

Source

impl RuntimePlugin for DeletePolicy

Source

impl RuntimePlugin for DeleteRule

Source

impl RuntimePlugin for DeleteScope

Source

impl RuntimePlugin for DeleteTemplate

Source

impl RuntimePlugin for GenerateRuleConfiguration

Source

impl RuntimePlugin for GetAdminAccount

Source

impl RuntimePlugin for GetDeployment

Source

impl RuntimePlugin for GetPolicy

Source

impl RuntimePlugin for GetRule

Source

impl RuntimePlugin for GetScope

Source

impl RuntimePlugin for GetTemplate

Source

impl RuntimePlugin for ListAdminAccounts

Source

impl RuntimePlugin for ListAggregateResourceSynchronizationStatuses

Source

impl RuntimePlugin for ListDeploymentSnapshots

Source

impl RuntimePlugin for ListDeployments

Source

impl RuntimePlugin for ListPolicies

Source

impl RuntimePlugin for ListPolicySnapshots

Source

impl RuntimePlugin for ListResourceAssociations

Source

impl RuntimePlugin for ListResourceSynchronizationStatuses

Source

impl RuntimePlugin for ListRuleSnapshots

Source

impl RuntimePlugin for ListRules

Source

impl RuntimePlugin for ListScopeSnapshots

Source

impl RuntimePlugin for ListScopes

Source

impl RuntimePlugin for ListTagsForResource

Source

impl RuntimePlugin for ListTemplateSnapshots

Source

impl RuntimePlugin for ListTemplates

Source

impl RuntimePlugin for PutAdminAccount

Source

impl RuntimePlugin for SharedRuntimePlugin

Source

impl RuntimePlugin for StaticRuntimePlugin

Source

impl RuntimePlugin for TagResource

Source

impl RuntimePlugin for UntagResource

Source

impl RuntimePlugin for UpdateDeployment

Source

impl RuntimePlugin for UpdatePolicy

Source

impl RuntimePlugin for UpdateRule

Source

impl RuntimePlugin for UpdateScope

Source

impl RuntimePlugin for UpdateTemplate