pub struct CreateDeploymentFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateDeployment.
Creates a deployment. A deployment applies one or more policies to the accounts and resources selected by a scope. Use isPublished to create the deployment in published (ACTIVE) or draft (DRAFT) state. The response includes coverage information and any warnings about the deployment.
Implementations
Sourceimpl CreateDeploymentFluentBuilder
impl CreateDeploymentFluentBuilder
Sourcepub fn as_input(&self) -> &CreateDeploymentInputBuilder
pub fn as_input(&self) -> &CreateDeploymentInputBuilder
Access the CreateDeployment as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateDeploymentOutput, SdkError<CreateDeploymentError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateDeploymentOutput, SdkError<CreateDeploymentError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateDeploymentOutput, CreateDeploymentError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateDeploymentOutput, CreateDeploymentError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn deployment_name(self, input: impl Into<String>) -> Self
pub fn deployment_name(self, input: impl Into<String>) -> Self
The name of the deployment.
Sourcepub fn set_deployment_name(self, input: Option<String>) -> Self
pub fn set_deployment_name(self, input: Option<String>) -> Self
The name of the deployment.
Sourcepub fn get_deployment_name(&self) -> &Option<String>
pub fn get_deployment_name(&self) -> &Option<String>
The name of the deployment.
Sourcepub fn deployment_description(self, input: impl Into<String>) -> Self
pub fn deployment_description(self, input: impl Into<String>) -> Self
A description of the deployment.
Sourcepub fn set_deployment_description(self, input: Option<String>) -> Self
pub fn set_deployment_description(self, input: Option<String>) -> Self
A description of the deployment.
Sourcepub fn get_deployment_description(&self) -> &Option<String>
pub fn get_deployment_description(&self) -> &Option<String>
A description of the deployment.
Sourcepub fn deployment_configuration(self, input: DeploymentConfiguration) -> Self
pub fn deployment_configuration(self, input: DeploymentConfiguration) -> Self
The configuration settings for the deployment.
Sourcepub fn set_deployment_configuration(
self,
input: Option<DeploymentConfiguration>,
) -> Self
pub fn set_deployment_configuration( self, input: Option<DeploymentConfiguration>, ) -> Self
The configuration settings for the deployment.
Sourcepub fn get_deployment_configuration(&self) -> &Option<DeploymentConfiguration>
pub fn get_deployment_configuration(&self) -> &Option<DeploymentConfiguration>
The configuration settings for the deployment.
Sourcepub fn associated_policy_list(self, input: PolicyReference) -> Self
pub fn associated_policy_list(self, input: PolicyReference) -> Self
Appends an item to associatedPolicyList.
To override the contents of this collection use set_associated_policy_list.
The policies associated with the deployment.
Sourcepub fn set_associated_policy_list(
self,
input: Option<Vec<PolicyReference>>,
) -> Self
pub fn set_associated_policy_list( self, input: Option<Vec<PolicyReference>>, ) -> Self
The policies associated with the deployment.
Sourcepub fn get_associated_policy_list(&self) -> &Option<Vec<PolicyReference>>
pub fn get_associated_policy_list(&self) -> &Option<Vec<PolicyReference>>
The policies associated with the deployment.
Sourcepub fn associated_scope_list(self, input: ScopeReference) -> Self
pub fn associated_scope_list(self, input: ScopeReference) -> Self
Appends an item to associatedScopeList.
To override the contents of this collection use set_associated_scope_list.
The scope associated with the deployment. A deployment has exactly one scope.
Sourcepub fn set_associated_scope_list(
self,
input: Option<Vec<ScopeReference>>,
) -> Self
pub fn set_associated_scope_list( self, input: Option<Vec<ScopeReference>>, ) -> Self
The scope associated with the deployment. A deployment has exactly one scope.
Sourcepub fn get_associated_scope_list(&self) -> &Option<Vec<ScopeReference>>
pub fn get_associated_scope_list(&self) -> &Option<Vec<ScopeReference>>
The scope associated with the deployment. A deployment has exactly one scope.
Sourcepub fn is_published(self, input: bool) -> Self
pub fn is_published(self, input: bool) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Sourcepub fn set_is_published(self, input: Option<bool>) -> Self
pub fn set_is_published(self, input: Option<bool>) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Sourcepub fn get_is_published(&self) -> &Option<bool>
pub fn get_is_published(&self) -> &Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags to add to the resource when it is created.
The tags to add to the resource when it is created.
The tags to add to the resource when it is created.