#[non_exhaustive]pub struct CreateDeploymentInputBuilder { /* private fields */ }Expand description
A builder for CreateDeploymentInput.
Implementations
Sourceimpl CreateDeploymentInputBuilder
impl CreateDeploymentInputBuilder
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn deployment_name(self, input: impl Into<String>) -> Self
pub fn deployment_name(self, input: impl Into<String>) -> Self
The name of the deployment.
This field is required.Sourcepub fn set_deployment_name(self, input: Option<String>) -> Self
pub fn set_deployment_name(self, input: Option<String>) -> Self
The name of the deployment.
Sourcepub fn get_deployment_name(&self) -> &Option<String>
pub fn get_deployment_name(&self) -> &Option<String>
The name of the deployment.
Sourcepub fn deployment_description(self, input: impl Into<String>) -> Self
pub fn deployment_description(self, input: impl Into<String>) -> Self
A description of the deployment.
Sourcepub fn set_deployment_description(self, input: Option<String>) -> Self
pub fn set_deployment_description(self, input: Option<String>) -> Self
A description of the deployment.
Sourcepub fn get_deployment_description(&self) -> &Option<String>
pub fn get_deployment_description(&self) -> &Option<String>
A description of the deployment.
Sourcepub fn deployment_configuration(self, input: DeploymentConfiguration) -> Self
pub fn deployment_configuration(self, input: DeploymentConfiguration) -> Self
The configuration settings for the deployment.
This field is required.Sourcepub fn set_deployment_configuration(
self,
input: Option<DeploymentConfiguration>,
) -> Self
pub fn set_deployment_configuration( self, input: Option<DeploymentConfiguration>, ) -> Self
The configuration settings for the deployment.
Sourcepub fn get_deployment_configuration(&self) -> &Option<DeploymentConfiguration>
pub fn get_deployment_configuration(&self) -> &Option<DeploymentConfiguration>
The configuration settings for the deployment.
Sourcepub fn associated_policy_list(self, input: PolicyReference) -> Self
pub fn associated_policy_list(self, input: PolicyReference) -> Self
Appends an item to associated_policy_list.
To override the contents of this collection use set_associated_policy_list.
The policies associated with the deployment.
Sourcepub fn set_associated_policy_list(
self,
input: Option<Vec<PolicyReference>>,
) -> Self
pub fn set_associated_policy_list( self, input: Option<Vec<PolicyReference>>, ) -> Self
The policies associated with the deployment.
Sourcepub fn get_associated_policy_list(&self) -> &Option<Vec<PolicyReference>>
pub fn get_associated_policy_list(&self) -> &Option<Vec<PolicyReference>>
The policies associated with the deployment.
Sourcepub fn associated_scope_list(self, input: ScopeReference) -> Self
pub fn associated_scope_list(self, input: ScopeReference) -> Self
Appends an item to associated_scope_list.
To override the contents of this collection use set_associated_scope_list.
The scope associated with the deployment. A deployment has exactly one scope.
Sourcepub fn set_associated_scope_list(
self,
input: Option<Vec<ScopeReference>>,
) -> Self
pub fn set_associated_scope_list( self, input: Option<Vec<ScopeReference>>, ) -> Self
The scope associated with the deployment. A deployment has exactly one scope.
Sourcepub fn get_associated_scope_list(&self) -> &Option<Vec<ScopeReference>>
pub fn get_associated_scope_list(&self) -> &Option<Vec<ScopeReference>>
The scope associated with the deployment. A deployment has exactly one scope.
Sourcepub fn is_published(self, input: bool) -> Self
pub fn is_published(self, input: bool) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Sourcepub fn set_is_published(self, input: Option<bool>) -> Self
pub fn set_is_published(self, input: Option<bool>) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Sourcepub fn get_is_published(&self) -> &Option<bool>
pub fn get_is_published(&self) -> &Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags to add to the resource when it is created.
The tags to add to the resource when it is created.
The tags to add to the resource when it is created.
Sourcepub fn build(self) -> Result<CreateDeploymentInput, BuildError>
pub fn build(self) -> Result<CreateDeploymentInput, BuildError>
Consumes the builder and constructs a CreateDeploymentInput.
Sourceimpl CreateDeploymentInputBuilder
impl CreateDeploymentInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateDeploymentOutput, SdkError<CreateDeploymentError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateDeploymentOutput, SdkError<CreateDeploymentError, HttpResponse>>
Sends a request with this input using the given client.