#[non_exhaustive]pub struct CreateDeploymentInput {
pub client_token: Option<String>,
pub deployment_name: Option<String>,
pub deployment_description: Option<String>,
pub deployment_configuration: Option<DeploymentConfiguration>,
pub associated_policy_list: Option<Vec<PolicyReference>>,
pub associated_scope_list: Option<Vec<ScopeReference>>,
pub is_published: Option<bool>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_token: Option<String>A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
deployment_name: Option<String>The name of the deployment.
deployment_description: Option<String>A description of the deployment.
deployment_configuration: Option<DeploymentConfiguration>The configuration settings for the deployment.
associated_policy_list: Option<Vec<PolicyReference>>The policies associated with the deployment.
associated_scope_list: Option<Vec<ScopeReference>>The scope associated with the deployment. A deployment has exactly one scope.
is_published: Option<bool>Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
The tags to add to the resource when it is created.
Implementations
Sourceimpl CreateDeploymentInput
impl CreateDeploymentInput
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn deployment_name(&self) -> Option<&str>
pub fn deployment_name(&self) -> Option<&str>
The name of the deployment.
Sourcepub fn deployment_description(&self) -> Option<&str>
pub fn deployment_description(&self) -> Option<&str>
A description of the deployment.
Sourcepub fn deployment_configuration(&self) -> Option<&DeploymentConfiguration>
pub fn deployment_configuration(&self) -> Option<&DeploymentConfiguration>
The configuration settings for the deployment.
Sourcepub fn associated_policy_list(&self) -> &[PolicyReference]
pub fn associated_policy_list(&self) -> &[PolicyReference]
The policies associated with the deployment.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .associated_policy_list.is_none().
Sourcepub fn associated_scope_list(&self) -> &[ScopeReference]
pub fn associated_scope_list(&self) -> &[ScopeReference]
The scope associated with the deployment. A deployment has exactly one scope.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .associated_scope_list.is_none().
Sourcepub fn is_published(&self) -> Option<bool>
pub fn is_published(&self) -> Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
The tags to add to the resource when it is created.
Sourceimpl CreateDeploymentInput
impl CreateDeploymentInput
Sourcepub fn builder() -> CreateDeploymentInputBuilder
pub fn builder() -> CreateDeploymentInputBuilder
Creates a new builder-style object to manufacture CreateDeploymentInput.