CreateDeploymentOutput

Struct CreateDeploymentOutput 

#[non_exhaustive]
pub struct CreateDeploymentOutput {
Show 15 fields pub deployment_id: String, pub deployment_arn: String, pub deployment_name: String, pub deployment_description: Option<String>, pub status: EntityStatus, pub deployment_configuration: Option<DeploymentConfiguration>, pub associated_policy_list: Vec<AssociatedPolicy>, pub associated_scope_list: Vec<AssociatedScope>, pub version: String, pub update_token: Option<String>, pub is_snapshot: Option<bool>, pub has_published_version: Option<bool>, pub deployment_coverage: Option<Vec<DeploymentCoverageEntry>>, pub warnings: Option<Vec<DeploymentWarningEntry>>, pub updated_at: Option<DateTime>, /* private fields */
}

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
deployment_id: String

The service-generated id of the deployment.

deployment_arn: String

The Amazon Resource Name (ARN) of the deployment.

deployment_name: String

The name of the deployment.

deployment_description: Option<String>

A description of the deployment.

status: EntityStatus

The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).

deployment_configuration: Option<DeploymentConfiguration>

The configuration settings for the deployment.

associated_policy_list: Vec<AssociatedPolicy>

The policies associated with the deployment.

associated_scope_list: Vec<AssociatedScope>

The scope associated with the deployment. A deployment has exactly one scope.

version: String

The version of the resource.

update_token: Option<String>

A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.

is_snapshot: Option<bool>

Specifies whether the resource is a snapshot of a published version.

has_published_version: Option<bool>

Specifies whether a published version of the resource exists.

deployment_coverage: Option<Vec<DeploymentCoverageEntry>>

The coverage information for the deployment. For each firewall type, it shows which policies have that firewall type and which in-scope resource types the firewall type protects.

warnings: Option<Vec<DeploymentWarningEntry>>

Warnings about potential issues, such as a policy that has no applicable resources in the deployment's scope.

updated_at: Option<DateTime>

The time when the resource was last updated.

Implementations

Source

impl CreateDeploymentOutput

pub fn deployment_id(&self) -> &str

The service-generated id of the deployment.

pub fn deployment_arn(&self) -> &str

The Amazon Resource Name (ARN) of the deployment.

pub fn deployment_name(&self) -> &str

The name of the deployment.

pub fn deployment_description(&self) -> Option<&str>

A description of the deployment.

pub fn status(&self) -> &EntityStatus

The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).

pub fn deployment_configuration(&self) -> Option<&DeploymentConfiguration>

The configuration settings for the deployment.

pub fn associated_policy_list(&self) -> &[AssociatedPolicy]

The policies associated with the deployment.

pub fn associated_scope_list(&self) -> &[AssociatedScope]

The scope associated with the deployment. A deployment has exactly one scope.

pub fn version(&self) -> &str

The version of the resource.

pub fn update_token(&self) -> Option<&str>

A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.

pub fn is_snapshot(&self) -> Option<bool>

Specifies whether the resource is a snapshot of a published version.

pub fn has_published_version(&self) -> Option<bool>

Specifies whether a published version of the resource exists.

pub fn deployment_coverage(&self) -> &[DeploymentCoverageEntry]

The coverage information for the deployment. For each firewall type, it shows which policies have that firewall type and which in-scope resource types the firewall type protects.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .deployment_coverage.is_none().

pub fn warnings(&self) -> &[DeploymentWarningEntry]

Warnings about potential issues, such as a policy that has no applicable resources in the deployment's scope.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .warnings.is_none().

pub fn updated_at(&self) -> Option<&DateTime>

The time when the resource was last updated.

Source

impl CreateDeploymentOutput

pub fn builder() -> CreateDeploymentOutputBuilder

Creates a new builder-style object to manufacture CreateDeploymentOutput.