pub struct CreatePolicyFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreatePolicy.
Creates a policy. A policy combines templates and rules with enforcement settings for a firewall type, such as AWS WAF or AWS Shield Advanced. Use isPublished to create the policy in published (ACTIVE) or draft (DRAFT) state.
Implementations
Sourceimpl CreatePolicyFluentBuilder
impl CreatePolicyFluentBuilder
Sourcepub fn as_input(&self) -> &CreatePolicyInputBuilder
pub fn as_input(&self) -> &CreatePolicyInputBuilder
Access the CreatePolicy as a reference.
Sourcepub async fn send(
self,
) -> Result<CreatePolicyOutput, SdkError<CreatePolicyError, HttpResponse>>
pub async fn send( self, ) -> Result<CreatePolicyOutput, SdkError<CreatePolicyError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreatePolicyOutput, CreatePolicyError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreatePolicyOutput, CreatePolicyError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn policy_name(self, input: impl Into<String>) -> Self
pub fn policy_name(self, input: impl Into<String>) -> Self
The name of the policy.
Sourcepub fn set_policy_name(self, input: Option<String>) -> Self
pub fn set_policy_name(self, input: Option<String>) -> Self
The name of the policy.
Sourcepub fn get_policy_name(&self) -> &Option<String>
pub fn get_policy_name(&self) -> &Option<String>
The name of the policy.
Sourcepub fn policy_description(self, input: impl Into<String>) -> Self
pub fn policy_description(self, input: impl Into<String>) -> Self
A description of the policy.
Sourcepub fn set_policy_description(self, input: Option<String>) -> Self
pub fn set_policy_description(self, input: Option<String>) -> Self
A description of the policy.
Sourcepub fn get_policy_description(&self) -> &Option<String>
pub fn get_policy_description(&self) -> &Option<String>
A description of the policy.
Sourcepub fn priority(self, input: i32) -> Self
pub fn priority(self, input: i32) -> Self
The priority of the resource. A lower number indicates a higher priority.
Sourcepub fn set_priority(self, input: Option<i32>) -> Self
pub fn set_priority(self, input: Option<i32>) -> Self
The priority of the resource. A lower number indicates a higher priority.
Sourcepub fn get_priority(&self) -> &Option<i32>
pub fn get_priority(&self) -> &Option<i32>
The priority of the resource. A lower number indicates a higher priority.
Sourcepub fn associated_template_and_rule_list(
self,
input: TemplateOrRuleReference,
) -> Self
pub fn associated_template_and_rule_list( self, input: TemplateOrRuleReference, ) -> Self
Appends an item to associatedTemplateAndRuleList.
To override the contents of this collection use set_associated_template_and_rule_list.
The templates and rules to associate with the policy. For AWS WAF policies, specify 1 to 100 templates or rules, of which at most 2 can be templates. For AWS Shield Advanced policies, this list must be empty.
Sourcepub fn set_associated_template_and_rule_list(
self,
input: Option<Vec<TemplateOrRuleReference>>,
) -> Self
pub fn set_associated_template_and_rule_list( self, input: Option<Vec<TemplateOrRuleReference>>, ) -> Self
The templates and rules to associate with the policy. For AWS WAF policies, specify 1 to 100 templates or rules, of which at most 2 can be templates. For AWS Shield Advanced policies, this list must be empty.
Sourcepub fn get_associated_template_and_rule_list(
&self,
) -> &Option<Vec<TemplateOrRuleReference>>
pub fn get_associated_template_and_rule_list( &self, ) -> &Option<Vec<TemplateOrRuleReference>>
The templates and rules to associate with the policy. For AWS WAF policies, specify 1 to 100 templates or rules, of which at most 2 can be templates. For AWS Shield Advanced policies, this list must be empty.
Sourcepub fn firewall_type(self, input: PolicyFirewallType) -> Self
pub fn firewall_type(self, input: PolicyFirewallType) -> Self
The firewall type associated with the resource.
Sourcepub fn set_firewall_type(self, input: Option<PolicyFirewallType>) -> Self
pub fn set_firewall_type(self, input: Option<PolicyFirewallType>) -> Self
The firewall type associated with the resource.
Sourcepub fn get_firewall_type(&self) -> &Option<PolicyFirewallType>
pub fn get_firewall_type(&self) -> &Option<PolicyFirewallType>
The firewall type associated with the resource.
Sourcepub fn policy_configuration(self, input: PolicyConfiguration) -> Self
pub fn policy_configuration(self, input: PolicyConfiguration) -> Self
The configuration settings that control the policy's behavior, including remediation and firewall-type-specific settings.
Sourcepub fn set_policy_configuration(
self,
input: Option<PolicyConfiguration>,
) -> Self
pub fn set_policy_configuration( self, input: Option<PolicyConfiguration>, ) -> Self
The configuration settings that control the policy's behavior, including remediation and firewall-type-specific settings.
Sourcepub fn get_policy_configuration(&self) -> &Option<PolicyConfiguration>
pub fn get_policy_configuration(&self) -> &Option<PolicyConfiguration>
The configuration settings that control the policy's behavior, including remediation and firewall-type-specific settings.
Sourcepub fn is_published(self, input: bool) -> Self
pub fn is_published(self, input: bool) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Sourcepub fn set_is_published(self, input: Option<bool>) -> Self
pub fn set_is_published(self, input: Option<bool>) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Sourcepub fn get_is_published(&self) -> &Option<bool>
pub fn get_is_published(&self) -> &Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags to add to the resource when it is created.
The tags to add to the resource when it is created.
The tags to add to the resource when it is created.