#[non_exhaustive]pub struct CreatePolicyOutputBuilder { /* private fields */ }Expand description
A builder for CreatePolicyOutput.
Implementations
Sourceimpl CreatePolicyOutputBuilder
impl CreatePolicyOutputBuilder
Sourcepub fn policy_id(self, input: impl Into<String>) -> Self
pub fn policy_id(self, input: impl Into<String>) -> Self
The service-generated id of the policy.
This field is required.Sourcepub fn set_policy_id(self, input: Option<String>) -> Self
pub fn set_policy_id(self, input: Option<String>) -> Self
The service-generated id of the policy.
Sourcepub fn get_policy_id(&self) -> &Option<String>
pub fn get_policy_id(&self) -> &Option<String>
The service-generated id of the policy.
Sourcepub fn policy_arn(self, input: impl Into<String>) -> Self
pub fn policy_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the policy.
This field is required.Sourcepub fn set_policy_arn(self, input: Option<String>) -> Self
pub fn set_policy_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the policy.
Sourcepub fn get_policy_arn(&self) -> &Option<String>
pub fn get_policy_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the policy.
Sourcepub fn policy_name(self, input: impl Into<String>) -> Self
pub fn policy_name(self, input: impl Into<String>) -> Self
The name of the policy.
This field is required.Sourcepub fn set_policy_name(self, input: Option<String>) -> Self
pub fn set_policy_name(self, input: Option<String>) -> Self
The name of the policy.
Sourcepub fn get_policy_name(&self) -> &Option<String>
pub fn get_policy_name(&self) -> &Option<String>
The name of the policy.
Sourcepub fn policy_description(self, input: impl Into<String>) -> Self
pub fn policy_description(self, input: impl Into<String>) -> Self
A description of the policy.
Sourcepub fn set_policy_description(self, input: Option<String>) -> Self
pub fn set_policy_description(self, input: Option<String>) -> Self
A description of the policy.
Sourcepub fn get_policy_description(&self) -> &Option<String>
pub fn get_policy_description(&self) -> &Option<String>
A description of the policy.
Sourcepub fn status(self, input: EntityStatus) -> Self
pub fn status(self, input: EntityStatus) -> Self
The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
Sourcepub fn set_status(self, input: Option<EntityStatus>) -> Self
pub fn set_status(self, input: Option<EntityStatus>) -> Self
The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
Sourcepub fn get_status(&self) -> &Option<EntityStatus>
pub fn get_status(&self) -> &Option<EntityStatus>
The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
Sourcepub fn priority(self, input: i32) -> Self
pub fn priority(self, input: i32) -> Self
The priority of the resource. A lower number indicates a higher priority.
This field is required.Sourcepub fn set_priority(self, input: Option<i32>) -> Self
pub fn set_priority(self, input: Option<i32>) -> Self
The priority of the resource. A lower number indicates a higher priority.
Sourcepub fn get_priority(&self) -> &Option<i32>
pub fn get_priority(&self) -> &Option<i32>
The priority of the resource. A lower number indicates a higher priority.
Sourcepub fn associated_template_and_rule_list(
self,
input: AssociatedTemplateOrRule,
) -> Self
pub fn associated_template_and_rule_list( self, input: AssociatedTemplateOrRule, ) -> Self
Appends an item to associated_template_and_rule_list.
To override the contents of this collection use set_associated_template_and_rule_list.
The templates and rules associated with the policy. For AWS WAF policies, this list contains 1 to 100 templates or rules, of which at most 2 can be templates. For AWS Shield Advanced policies, this list is empty.
Sourcepub fn set_associated_template_and_rule_list(
self,
input: Option<Vec<AssociatedTemplateOrRule>>,
) -> Self
pub fn set_associated_template_and_rule_list( self, input: Option<Vec<AssociatedTemplateOrRule>>, ) -> Self
The templates and rules associated with the policy. For AWS WAF policies, this list contains 1 to 100 templates or rules, of which at most 2 can be templates. For AWS Shield Advanced policies, this list is empty.
Sourcepub fn get_associated_template_and_rule_list(
&self,
) -> &Option<Vec<AssociatedTemplateOrRule>>
pub fn get_associated_template_and_rule_list( &self, ) -> &Option<Vec<AssociatedTemplateOrRule>>
The templates and rules associated with the policy. For AWS WAF policies, this list contains 1 to 100 templates or rules, of which at most 2 can be templates. For AWS Shield Advanced policies, this list is empty.
Sourcepub fn version(self, input: impl Into<String>) -> Self
pub fn version(self, input: impl Into<String>) -> Self
The version of the resource.
This field is required.Sourcepub fn set_version(self, input: Option<String>) -> Self
pub fn set_version(self, input: Option<String>) -> Self
The version of the resource.
Sourcepub fn get_version(&self) -> &Option<String>
pub fn get_version(&self) -> &Option<String>
The version of the resource.
Sourcepub fn update_token(self, input: impl Into<String>) -> Self
pub fn update_token(self, input: impl Into<String>) -> Self
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn set_update_token(self, input: Option<String>) -> Self
pub fn set_update_token(self, input: Option<String>) -> Self
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn get_update_token(&self) -> &Option<String>
pub fn get_update_token(&self) -> &Option<String>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn is_snapshot(self, input: bool) -> Self
pub fn is_snapshot(self, input: bool) -> Self
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn set_is_snapshot(self, input: Option<bool>) -> Self
pub fn set_is_snapshot(self, input: Option<bool>) -> Self
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn get_is_snapshot(&self) -> &Option<bool>
pub fn get_is_snapshot(&self) -> &Option<bool>
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn has_published_version(self, input: bool) -> Self
pub fn has_published_version(self, input: bool) -> Self
Specifies whether a published version of the resource exists.
Sourcepub fn set_has_published_version(self, input: Option<bool>) -> Self
pub fn set_has_published_version(self, input: Option<bool>) -> Self
Specifies whether a published version of the resource exists.
Sourcepub fn get_has_published_version(&self) -> &Option<bool>
pub fn get_has_published_version(&self) -> &Option<bool>
Specifies whether a published version of the resource exists.
Sourcepub fn firewall_type(self, input: PolicyFirewallType) -> Self
pub fn firewall_type(self, input: PolicyFirewallType) -> Self
The firewall type associated with the resource.
This field is required.Sourcepub fn set_firewall_type(self, input: Option<PolicyFirewallType>) -> Self
pub fn set_firewall_type(self, input: Option<PolicyFirewallType>) -> Self
The firewall type associated with the resource.
Sourcepub fn get_firewall_type(&self) -> &Option<PolicyFirewallType>
pub fn get_firewall_type(&self) -> &Option<PolicyFirewallType>
The firewall type associated with the resource.
Sourcepub fn policy_configuration(self, input: PolicyConfiguration) -> Self
pub fn policy_configuration(self, input: PolicyConfiguration) -> Self
The configuration settings that control the policy's behavior, including remediation and firewall-type-specific settings.
Sourcepub fn set_policy_configuration(
self,
input: Option<PolicyConfiguration>,
) -> Self
pub fn set_policy_configuration( self, input: Option<PolicyConfiguration>, ) -> Self
The configuration settings that control the policy's behavior, including remediation and firewall-type-specific settings.
Sourcepub fn get_policy_configuration(&self) -> &Option<PolicyConfiguration>
pub fn get_policy_configuration(&self) -> &Option<PolicyConfiguration>
The configuration settings that control the policy's behavior, including remediation and firewall-type-specific settings.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The time when the resource was last updated.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The time when the resource was last updated.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The time when the resource was last updated.
Sourcepub fn build(self) -> Result<CreatePolicyOutput, BuildError>
pub fn build(self) -> Result<CreatePolicyOutput, BuildError>
Consumes the builder and constructs a CreatePolicyOutput.
This method will fail if any of the following fields are not set: