CreatePolicyInput

Struct CreatePolicyInput 

#[non_exhaustive]
pub struct CreatePolicyInput { pub client_token: Option<String>, pub policy_name: Option<String>, pub policy_description: Option<String>, pub priority: Option<i32>, pub associated_template_and_rule_list: Option<Vec<TemplateOrRuleReference>>, pub firewall_type: Option<PolicyFirewallType>, pub policy_configuration: Option<PolicyConfiguration>, pub is_published: Option<bool>, pub tags: Option<HashMap<String, String>>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
client_token: Option<String>

A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.

policy_name: Option<String>

The name of the policy.

policy_description: Option<String>

A description of the policy.

priority: Option<i32>

The priority of the resource. A lower number indicates a higher priority.

associated_template_and_rule_list: Option<Vec<TemplateOrRuleReference>>

The templates and rules to associate with the policy. For AWS WAF policies, specify 1 to 100 templates or rules, of which at most 2 can be templates. For AWS Shield Advanced policies, this list must be empty.

firewall_type: Option<PolicyFirewallType>

The firewall type associated with the resource.

policy_configuration: Option<PolicyConfiguration>

The configuration settings that control the policy's behavior, including remediation and firewall-type-specific settings.

is_published: Option<bool>

Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.

tags: Option<HashMap<String, String>>

The tags to add to the resource when it is created.

Implementations

Source

impl CreatePolicyInput

pub fn client_token(&self) -> Option<&str>

A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.

pub fn policy_name(&self) -> Option<&str>

The name of the policy.

pub fn policy_description(&self) -> Option<&str>

A description of the policy.

pub fn priority(&self) -> Option<i32>

The priority of the resource. A lower number indicates a higher priority.

pub fn associated_template_and_rule_list(&self) -> &[TemplateOrRuleReference]

The templates and rules to associate with the policy. For AWS WAF policies, specify 1 to 100 templates or rules, of which at most 2 can be templates. For AWS Shield Advanced policies, this list must be empty.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .associated_template_and_rule_list.is_none().

pub fn firewall_type(&self) -> Option<&PolicyFirewallType>

The firewall type associated with the resource.

pub fn policy_configuration(&self) -> Option<&PolicyConfiguration>

The configuration settings that control the policy's behavior, including remediation and firewall-type-specific settings.

pub fn is_published(&self) -> Option<bool>

Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.

pub fn tags(&self) -> Option<&HashMap<String, String>>

The tags to add to the resource when it is created.

Source

impl CreatePolicyInput

pub fn builder() -> CreatePolicyInputBuilder

Creates a new builder-style object to manufacture CreatePolicyInput.