#[non_exhaustive]pub struct CreatePolicySnapshotInput {
pub policy_identifier: Option<String>,
pub client_token: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.policy_identifier: Option<String>The identifier of the policy. This is the policy's Amazon Resource Name (ARN).
client_token: Option<String>A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
The tags to add to the snapshot when it is created.
Implementations
Sourceimpl CreatePolicySnapshotInput
impl CreatePolicySnapshotInput
Sourcepub fn policy_identifier(&self) -> Option<&str>
pub fn policy_identifier(&self) -> Option<&str>
The identifier of the policy. This is the policy's Amazon Resource Name (ARN).
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
The tags to add to the snapshot when it is created.
Sourceimpl CreatePolicySnapshotInput
impl CreatePolicySnapshotInput
Sourcepub fn builder() -> CreatePolicySnapshotInputBuilder
pub fn builder() -> CreatePolicySnapshotInputBuilder
Creates a new builder-style object to manufacture CreatePolicySnapshotInput.