pub struct CreateRuleFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateRule.
Creates a rule. A rule defines a network security configuration to enforce, such as an AWS WAF rule group or configuration data. Use isPublished to create the rule in published (ACTIVE) or draft (DRAFT) state.
Implementations
Sourceimpl CreateRuleFluentBuilder
impl CreateRuleFluentBuilder
Sourcepub fn as_input(&self) -> &CreateRuleInputBuilder
pub fn as_input(&self) -> &CreateRuleInputBuilder
Access the CreateRule as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateRuleOutput, SdkError<CreateRuleError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateRuleOutput, SdkError<CreateRuleError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateRuleOutput, CreateRuleError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateRuleOutput, CreateRuleError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn set_rule_name(self, input: Option<String>) -> Self
pub fn set_rule_name(self, input: Option<String>) -> Self
The name of the rule.
Sourcepub fn get_rule_name(&self) -> &Option<String>
pub fn get_rule_name(&self) -> &Option<String>
The name of the rule.
Sourcepub fn firewall_type(self, input: RuleFirewallType) -> Self
pub fn firewall_type(self, input: RuleFirewallType) -> Self
The firewall type associated with the resource.
Sourcepub fn set_firewall_type(self, input: Option<RuleFirewallType>) -> Self
pub fn set_firewall_type(self, input: Option<RuleFirewallType>) -> Self
The firewall type associated with the resource.
Sourcepub fn get_firewall_type(&self) -> &Option<RuleFirewallType>
pub fn get_firewall_type(&self) -> &Option<RuleFirewallType>
The firewall type associated with the resource.
Sourcepub fn rule_type(self, input: RuleType) -> Self
pub fn rule_type(self, input: RuleType) -> Self
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn set_rule_type(self, input: Option<RuleType>) -> Self
pub fn set_rule_type(self, input: Option<RuleType>) -> Self
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn get_rule_type(&self) -> &Option<RuleType>
pub fn get_rule_type(&self) -> &Option<RuleType>
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn rule_description(self, input: impl Into<String>) -> Self
pub fn rule_description(self, input: impl Into<String>) -> Self
A description of the rule.
Sourcepub fn set_rule_description(self, input: Option<String>) -> Self
pub fn set_rule_description(self, input: Option<String>) -> Self
A description of the rule.
Sourcepub fn get_rule_description(&self) -> &Option<String>
pub fn get_rule_description(&self) -> &Option<String>
A description of the rule.
Sourcepub fn configuration(self, input: Document) -> Self
pub fn configuration(self, input: Document) -> Self
The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type. For an AWS WAF INSPECTION rule, provide an AWS WAF rule group. For an AWS WAF CONFIGURATION rule, provide a single web ACL setting, such as DefaultAction or VisibilityConfig; use wafConfigDataType to declare which setting the document contains. For the schema of each setting and complete examples, see Writing rule configurations in the AWS Network Security Manager Developer Guide.
Sourcepub fn set_configuration(self, input: Option<Document>) -> Self
pub fn set_configuration(self, input: Option<Document>) -> Self
The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type. For an AWS WAF INSPECTION rule, provide an AWS WAF rule group. For an AWS WAF CONFIGURATION rule, provide a single web ACL setting, such as DefaultAction or VisibilityConfig; use wafConfigDataType to declare which setting the document contains. For the schema of each setting and complete examples, see Writing rule configurations in the AWS Network Security Manager Developer Guide.
Sourcepub fn get_configuration(&self) -> &Option<Document>
pub fn get_configuration(&self) -> &Option<Document>
The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type. For an AWS WAF INSPECTION rule, provide an AWS WAF rule group. For an AWS WAF CONFIGURATION rule, provide a single web ACL setting, such as DefaultAction or VisibilityConfig; use wafConfigDataType to declare which setting the document contains. For the schema of each setting and complete examples, see Writing rule configurations in the AWS Network Security Manager Developer Guide.
Sourcepub fn is_published(self, input: bool) -> Self
pub fn is_published(self, input: bool) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Sourcepub fn set_is_published(self, input: Option<bool>) -> Self
pub fn set_is_published(self, input: Option<bool>) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Sourcepub fn get_is_published(&self) -> &Option<bool>
pub fn get_is_published(&self) -> &Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags to add to the resource when it is created.
The tags to add to the resource when it is created.
The tags to add to the resource when it is created.