#[non_exhaustive]pub struct CreateRuleInput {
pub client_token: Option<String>,
pub rule_name: Option<String>,
pub firewall_type: Option<RuleFirewallType>,
pub rule_type: Option<RuleType>,
pub rule_description: Option<String>,
pub configuration: Option<Document>,
pub is_published: Option<bool>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_token: Option<String>A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
rule_name: Option<String>The name of the rule.
firewall_type: Option<RuleFirewallType>The firewall type associated with the resource.
rule_type: Option<RuleType>The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
rule_description: Option<String>A description of the rule.
configuration: Option<Document>The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type. For an AWS WAF INSPECTION rule, provide an AWS WAF rule group. For an AWS WAF CONFIGURATION rule, provide a single web ACL setting, such as DefaultAction or VisibilityConfig; use wafConfigDataType to declare which setting the document contains. For the schema of each setting and complete examples, see Writing rule configurations in the AWS Network Security Manager Developer Guide.
is_published: Option<bool>Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
The tags to add to the resource when it is created.
Implementations
Sourceimpl CreateRuleInput
impl CreateRuleInput
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn firewall_type(&self) -> Option<&RuleFirewallType>
pub fn firewall_type(&self) -> Option<&RuleFirewallType>
The firewall type associated with the resource.
Sourcepub fn rule_type(&self) -> Option<&RuleType>
pub fn rule_type(&self) -> Option<&RuleType>
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn rule_description(&self) -> Option<&str>
pub fn rule_description(&self) -> Option<&str>
A description of the rule.
Sourcepub fn configuration(&self) -> Option<&Document>
pub fn configuration(&self) -> Option<&Document>
The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type. For an AWS WAF INSPECTION rule, provide an AWS WAF rule group. For an AWS WAF CONFIGURATION rule, provide a single web ACL setting, such as DefaultAction or VisibilityConfig; use wafConfigDataType to declare which setting the document contains. For the schema of each setting and complete examples, see Writing rule configurations in the AWS Network Security Manager Developer Guide.
Sourcepub fn is_published(&self) -> Option<bool>
pub fn is_published(&self) -> Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
The tags to add to the resource when it is created.
Sourceimpl CreateRuleInput
impl CreateRuleInput
Sourcepub fn builder() -> CreateRuleInputBuilder
pub fn builder() -> CreateRuleInputBuilder
Creates a new builder-style object to manufacture CreateRuleInput.