CreateRuleSnapshotOutputBuilder

Struct CreateRuleSnapshotOutputBuilder 

#[non_exhaustive]
pub struct CreateRuleSnapshotOutputBuilder { /* private fields */ }
A builder for CreateRuleSnapshotOutput.

Implementations

Source

impl CreateRuleSnapshotOutputBuilder

pub fn rule_id(self, input: impl Into<String>) -> Self

The service-generated id of the rule.

This field is required.
pub fn set_rule_id(self, input: Option<String>) -> Self

The service-generated id of the rule.

pub fn get_rule_id(&self) -> &Option<String>

The service-generated id of the rule.

pub fn rule_arn(self, input: impl Into<String>) -> Self

The Amazon Resource Name (ARN) of the rule.

This field is required.
pub fn set_rule_arn(self, input: Option<String>) -> Self

The Amazon Resource Name (ARN) of the rule.

pub fn get_rule_arn(&self) -> &Option<String>

The Amazon Resource Name (ARN) of the rule.

pub fn rule_name(self, input: impl Into<String>) -> Self

The name of the rule.

This field is required.
pub fn set_rule_name(self, input: Option<String>) -> Self

The name of the rule.

pub fn get_rule_name(&self) -> &Option<String>

The name of the rule.

pub fn firewall_type(self, input: RuleFirewallType) -> Self

The firewall type associated with the resource.

This field is required.
pub fn set_firewall_type(self, input: Option<RuleFirewallType>) -> Self

The firewall type associated with the resource.

pub fn get_firewall_type(&self) -> &Option<RuleFirewallType>

The firewall type associated with the resource.

pub fn rule_type(self, input: RuleType) -> Self

The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.

pub fn set_rule_type(self, input: Option<RuleType>) -> Self

The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.

pub fn get_rule_type(&self) -> &Option<RuleType>

The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.

pub fn rule_description(self, input: impl Into<String>) -> Self

A description of the rule.

pub fn set_rule_description(self, input: Option<String>) -> Self

A description of the rule.

pub fn get_rule_description(&self) -> &Option<String>

A description of the rule.

pub fn configuration(self, input: Document) -> Self

The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type.

This field is required.
pub fn set_configuration(self, input: Option<Document>) -> Self

The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type.

pub fn get_configuration(&self) -> &Option<Document>

The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type.

pub fn status(self, input: EntityStatus) -> Self

The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).

This field is required.
pub fn set_status(self, input: Option<EntityStatus>) -> Self

The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).

pub fn get_status(&self) -> &Option<EntityStatus>

The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).

pub fn version(self, input: impl Into<String>) -> Self

The version of the resource.

This field is required.
pub fn set_version(self, input: Option<String>) -> Self

The version of the resource.

pub fn get_version(&self) -> &Option<String>

The version of the resource.

pub fn update_token(self, input: impl Into<String>) -> Self

A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.

pub fn set_update_token(self, input: Option<String>) -> Self

A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.

pub fn get_update_token(&self) -> &Option<String>

A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.

pub fn is_snapshot(self, input: bool) -> Self

Specifies whether the resource is a snapshot of a published version.

pub fn set_is_snapshot(self, input: Option<bool>) -> Self

Specifies whether the resource is a snapshot of a published version.

pub fn get_is_snapshot(&self) -> &Option<bool>

Specifies whether the resource is a snapshot of a published version.

pub fn has_published_version(self, input: bool) -> Self

Specifies whether a published version of the resource exists.

pub fn set_has_published_version(self, input: Option<bool>) -> Self

Specifies whether a published version of the resource exists.

pub fn get_has_published_version(&self) -> &Option<bool>

Specifies whether a published version of the resource exists.

pub fn updated_at(self, input: DateTime) -> Self

The time when the snapshot was created.

pub fn set_updated_at(self, input: Option<DateTime>) -> Self

The time when the snapshot was created.

pub fn get_updated_at(&self) -> &Option<DateTime>

The time when the snapshot was created.

pub fn build(self) -> Result<CreateRuleSnapshotOutput, BuildError>

Consumes the builder and constructs a CreateRuleSnapshotOutput. This method will fail if any of the following fields are not set: