CreateScopeInputBuilder

Struct CreateScopeInputBuilder 

#[non_exhaustive]
pub struct CreateScopeInputBuilder { /* private fields */ }
A builder for CreateScopeInput.

Implementations

Source

impl CreateScopeInputBuilder

pub fn client_token(self, input: impl Into<String>) -> Self

A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.

pub fn set_client_token(self, input: Option<String>) -> Self

A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.

pub fn get_client_token(&self) -> &Option<String>

A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.

pub fn scope_name(self, input: impl Into<String>) -> Self

The name of the scope.

This field is required.
pub fn set_scope_name(self, input: Option<String>) -> Self

The name of the scope.

pub fn get_scope_name(&self) -> &Option<String>

The name of the scope.

pub fn scope_description(self, input: impl Into<String>) -> Self

A description of the scope.

pub fn set_scope_description(self, input: Option<String>) -> Self

A description of the scope.

pub fn get_scope_description(&self) -> &Option<String>

A description of the scope.

pub fn scope_configuration(self, input: ScopeConfiguration) -> Self

The configuration that defines which accounts and resources are in scope.

This field is required.
pub fn set_scope_configuration(self, input: Option<ScopeConfiguration>) -> Self

The configuration that defines which accounts and resources are in scope.

pub fn get_scope_configuration(&self) -> &Option<ScopeConfiguration>

The configuration that defines which accounts and resources are in scope.

pub fn is_published(self, input: bool) -> Self

Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.

pub fn set_is_published(self, input: Option<bool>) -> Self

Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.

pub fn get_is_published(&self) -> &Option<bool>

Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.

pub fn tags(self, k: impl Into<String>, v: impl Into<String>) -> Self

Adds a key-value pair to tags.

To override the contents of this collection use set_tags.

The tags to add to the resource when it is created.

pub fn set_tags(self, input: Option<HashMap<String, String>>) -> Self

The tags to add to the resource when it is created.

pub fn get_tags(&self) -> &Option<HashMap<String, String>>

The tags to add to the resource when it is created.

pub fn build(self) -> Result<CreateScopeInput, BuildError>

Consumes the builder and constructs a CreateScopeInput.

Source

impl CreateScopeInputBuilder

pub async fn send_with( self, client: &Client, ) -> Result<CreateScopeOutput, SdkError<CreateScopeError, HttpResponse>>

Sends a request with this input using the given client.