#[non_exhaustive]pub struct CreateScopeInput {
pub client_token: Option<String>,
pub scope_name: Option<String>,
pub scope_description: Option<String>,
pub scope_configuration: Option<ScopeConfiguration>,
pub is_published: Option<bool>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_token: Option<String>A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
scope_name: Option<String>The name of the scope.
scope_description: Option<String>A description of the scope.
scope_configuration: Option<ScopeConfiguration>The configuration that defines which accounts and resources are in scope.
is_published: Option<bool>Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
The tags to add to the resource when it is created.
Implementations
Sourceimpl CreateScopeInput
impl CreateScopeInput
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn scope_name(&self) -> Option<&str>
pub fn scope_name(&self) -> Option<&str>
The name of the scope.
Sourcepub fn scope_description(&self) -> Option<&str>
pub fn scope_description(&self) -> Option<&str>
A description of the scope.
Sourcepub fn scope_configuration(&self) -> Option<&ScopeConfiguration>
pub fn scope_configuration(&self) -> Option<&ScopeConfiguration>
The configuration that defines which accounts and resources are in scope.
Sourcepub fn is_published(&self) -> Option<bool>
pub fn is_published(&self) -> Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
The tags to add to the resource when it is created.
Sourceimpl CreateScopeInput
impl CreateScopeInput
Sourcepub fn builder() -> CreateScopeInputBuilder
pub fn builder() -> CreateScopeInputBuilder
Creates a new builder-style object to manufacture CreateScopeInput.