pub struct CreateScopeSnapshotFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateScopeSnapshot.
Creates a snapshot of the current published version of the specified scope.
Implementations
Sourceimpl CreateScopeSnapshotFluentBuilder
impl CreateScopeSnapshotFluentBuilder
Sourcepub fn as_input(&self) -> &CreateScopeSnapshotInputBuilder
pub fn as_input(&self) -> &CreateScopeSnapshotInputBuilder
Access the CreateScopeSnapshot as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateScopeSnapshotOutput, SdkError<CreateScopeSnapshotError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateScopeSnapshotOutput, SdkError<CreateScopeSnapshotError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateScopeSnapshotOutput, CreateScopeSnapshotError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateScopeSnapshotOutput, CreateScopeSnapshotError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn scope_identifier(self, input: impl Into<String>) -> Self
pub fn scope_identifier(self, input: impl Into<String>) -> Self
The identifier of the scope. This is the scope's Amazon Resource Name (ARN).
Sourcepub fn set_scope_identifier(self, input: Option<String>) -> Self
pub fn set_scope_identifier(self, input: Option<String>) -> Self
The identifier of the scope. This is the scope's Amazon Resource Name (ARN).
Sourcepub fn get_scope_identifier(&self) -> &Option<String>
pub fn get_scope_identifier(&self) -> &Option<String>
The identifier of the scope. This is the scope's Amazon Resource Name (ARN).
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags to add to the snapshot when it is created.
The tags to add to the snapshot when it is created.
The tags to add to the snapshot when it is created.