pub struct CreateTemplateFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateTemplate.
Creates a template. A template groups one or more rules to simplify reuse across policies. You can also associate rules with a policy directly, without a template. Use isPublished to create the template in published (ACTIVE) or draft (DRAFT) state.
Implementations
Sourceimpl CreateTemplateFluentBuilder
impl CreateTemplateFluentBuilder
Sourcepub fn as_input(&self) -> &CreateTemplateInputBuilder
pub fn as_input(&self) -> &CreateTemplateInputBuilder
Access the CreateTemplate as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateTemplateOutput, SdkError<CreateTemplateError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateTemplateOutput, SdkError<CreateTemplateError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateTemplateOutput, CreateTemplateError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateTemplateOutput, CreateTemplateError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn template_name(self, input: impl Into<String>) -> Self
pub fn template_name(self, input: impl Into<String>) -> Self
The name of the template.
Sourcepub fn set_template_name(self, input: Option<String>) -> Self
pub fn set_template_name(self, input: Option<String>) -> Self
The name of the template.
Sourcepub fn get_template_name(&self) -> &Option<String>
pub fn get_template_name(&self) -> &Option<String>
The name of the template.
Sourcepub fn template_description(self, input: impl Into<String>) -> Self
pub fn template_description(self, input: impl Into<String>) -> Self
A description of the template.
Sourcepub fn set_template_description(self, input: Option<String>) -> Self
pub fn set_template_description(self, input: Option<String>) -> Self
A description of the template.
Sourcepub fn get_template_description(&self) -> &Option<String>
pub fn get_template_description(&self) -> &Option<String>
A description of the template.
Sourcepub fn associated_rule_list(self, input: RuleReference) -> Self
pub fn associated_rule_list(self, input: RuleReference) -> Self
Appends an item to associatedRuleList.
To override the contents of this collection use set_associated_rule_list.
The rules associated with the template.
Sourcepub fn set_associated_rule_list(self, input: Option<Vec<RuleReference>>) -> Self
pub fn set_associated_rule_list(self, input: Option<Vec<RuleReference>>) -> Self
The rules associated with the template.
Sourcepub fn get_associated_rule_list(&self) -> &Option<Vec<RuleReference>>
pub fn get_associated_rule_list(&self) -> &Option<Vec<RuleReference>>
The rules associated with the template.
Sourcepub fn firewall_type(self, input: TemplateFirewallType) -> Self
pub fn firewall_type(self, input: TemplateFirewallType) -> Self
The firewall type associated with the resource.
Sourcepub fn set_firewall_type(self, input: Option<TemplateFirewallType>) -> Self
pub fn set_firewall_type(self, input: Option<TemplateFirewallType>) -> Self
The firewall type associated with the resource.
Sourcepub fn get_firewall_type(&self) -> &Option<TemplateFirewallType>
pub fn get_firewall_type(&self) -> &Option<TemplateFirewallType>
The firewall type associated with the resource.
Sourcepub fn is_published(self, input: bool) -> Self
pub fn is_published(self, input: bool) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Sourcepub fn set_is_published(self, input: Option<bool>) -> Self
pub fn set_is_published(self, input: Option<bool>) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Sourcepub fn get_is_published(&self) -> &Option<bool>
pub fn get_is_published(&self) -> &Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags to add to the resource when it is created.
The tags to add to the resource when it is created.
The tags to add to the resource when it is created.