#[non_exhaustive]pub struct CreateTemplateInputBuilder { /* private fields */ }Expand description
A builder for CreateTemplateInput.
Implementations
Sourceimpl CreateTemplateInputBuilder
impl CreateTemplateInputBuilder
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn template_name(self, input: impl Into<String>) -> Self
pub fn template_name(self, input: impl Into<String>) -> Self
The name of the template.
This field is required.Sourcepub fn set_template_name(self, input: Option<String>) -> Self
pub fn set_template_name(self, input: Option<String>) -> Self
The name of the template.
Sourcepub fn get_template_name(&self) -> &Option<String>
pub fn get_template_name(&self) -> &Option<String>
The name of the template.
Sourcepub fn template_description(self, input: impl Into<String>) -> Self
pub fn template_description(self, input: impl Into<String>) -> Self
A description of the template.
Sourcepub fn set_template_description(self, input: Option<String>) -> Self
pub fn set_template_description(self, input: Option<String>) -> Self
A description of the template.
Sourcepub fn get_template_description(&self) -> &Option<String>
pub fn get_template_description(&self) -> &Option<String>
A description of the template.
Sourcepub fn associated_rule_list(self, input: RuleReference) -> Self
pub fn associated_rule_list(self, input: RuleReference) -> Self
Appends an item to associated_rule_list.
To override the contents of this collection use set_associated_rule_list.
The rules associated with the template.
Sourcepub fn set_associated_rule_list(self, input: Option<Vec<RuleReference>>) -> Self
pub fn set_associated_rule_list(self, input: Option<Vec<RuleReference>>) -> Self
The rules associated with the template.
Sourcepub fn get_associated_rule_list(&self) -> &Option<Vec<RuleReference>>
pub fn get_associated_rule_list(&self) -> &Option<Vec<RuleReference>>
The rules associated with the template.
Sourcepub fn firewall_type(self, input: TemplateFirewallType) -> Self
pub fn firewall_type(self, input: TemplateFirewallType) -> Self
The firewall type associated with the resource.
This field is required.Sourcepub fn set_firewall_type(self, input: Option<TemplateFirewallType>) -> Self
pub fn set_firewall_type(self, input: Option<TemplateFirewallType>) -> Self
The firewall type associated with the resource.
Sourcepub fn get_firewall_type(&self) -> &Option<TemplateFirewallType>
pub fn get_firewall_type(&self) -> &Option<TemplateFirewallType>
The firewall type associated with the resource.
Sourcepub fn is_published(self, input: bool) -> Self
pub fn is_published(self, input: bool) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Sourcepub fn set_is_published(self, input: Option<bool>) -> Self
pub fn set_is_published(self, input: Option<bool>) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Sourcepub fn get_is_published(&self) -> &Option<bool>
pub fn get_is_published(&self) -> &Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags to add to the resource when it is created.
The tags to add to the resource when it is created.
The tags to add to the resource when it is created.
Sourcepub fn build(self) -> Result<CreateTemplateInput, BuildError>
pub fn build(self) -> Result<CreateTemplateInput, BuildError>
Consumes the builder and constructs a CreateTemplateInput.
Sourceimpl CreateTemplateInputBuilder
impl CreateTemplateInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateTemplateOutput, SdkError<CreateTemplateError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateTemplateOutput, SdkError<CreateTemplateError, HttpResponse>>
Sends a request with this input using the given client.