#[non_exhaustive]pub struct CreateTemplateInput {
pub client_token: Option<String>,
pub template_name: Option<String>,
pub template_description: Option<String>,
pub associated_rule_list: Option<Vec<RuleReference>>,
pub firewall_type: Option<TemplateFirewallType>,
pub is_published: Option<bool>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_token: Option<String>A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
template_name: Option<String>The name of the template.
template_description: Option<String>A description of the template.
associated_rule_list: Option<Vec<RuleReference>>The rules associated with the template.
firewall_type: Option<TemplateFirewallType>The firewall type associated with the resource.
is_published: Option<bool>Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
The tags to add to the resource when it is created.
Implementations
Sourceimpl CreateTemplateInput
impl CreateTemplateInput
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn template_name(&self) -> Option<&str>
pub fn template_name(&self) -> Option<&str>
The name of the template.
Sourcepub fn template_description(&self) -> Option<&str>
pub fn template_description(&self) -> Option<&str>
A description of the template.
Sourcepub fn associated_rule_list(&self) -> &[RuleReference]
pub fn associated_rule_list(&self) -> &[RuleReference]
The rules associated with the template.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .associated_rule_list.is_none().
Sourcepub fn firewall_type(&self) -> Option<&TemplateFirewallType>
pub fn firewall_type(&self) -> Option<&TemplateFirewallType>
The firewall type associated with the resource.
Sourcepub fn is_published(&self) -> Option<bool>
pub fn is_published(&self) -> Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT). Default: true.
The tags to add to the resource when it is created.
Sourceimpl CreateTemplateInput
impl CreateTemplateInput
Sourcepub fn builder() -> CreateTemplateInputBuilder
pub fn builder() -> CreateTemplateInputBuilder
Creates a new builder-style object to manufacture CreateTemplateInput.