#[non_exhaustive]pub struct CreateTemplateOutput {
pub template_id: String,
pub template_arn: String,
pub template_name: String,
pub template_description: Option<String>,
pub status: EntityStatus,
pub version: String,
pub associated_rule_list: Vec<AssociatedRule>,
pub update_token: Option<String>,
pub is_snapshot: Option<bool>,
pub has_published_version: Option<bool>,
pub firewall_type: TemplateFirewallType,
pub updated_at: Option<DateTime>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.template_id: StringThe service-generated id of the template.
template_arn: StringThe Amazon Resource Name (ARN) of the template.
template_name: StringThe name of the template.
template_description: Option<String>A description of the template.
status: EntityStatusThe current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
version: StringThe version of the resource.
associated_rule_list: Vec<AssociatedRule>The rules associated with the template.
update_token: Option<String>A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
is_snapshot: Option<bool>Specifies whether the resource is a snapshot of a published version.
has_published_version: Option<bool>Specifies whether a published version of the resource exists.
firewall_type: TemplateFirewallTypeThe firewall type associated with the resource.
updated_at: Option<DateTime>The time when the resource was last updated.
Implementations
Sourceimpl CreateTemplateOutput
impl CreateTemplateOutput
Sourcepub fn template_id(&self) -> &str
pub fn template_id(&self) -> &str
The service-generated id of the template.
Sourcepub fn template_arn(&self) -> &str
pub fn template_arn(&self) -> &str
The Amazon Resource Name (ARN) of the template.
Sourcepub fn template_name(&self) -> &str
pub fn template_name(&self) -> &str
The name of the template.
Sourcepub fn template_description(&self) -> Option<&str>
pub fn template_description(&self) -> Option<&str>
A description of the template.
Sourcepub fn status(&self) -> &EntityStatus
pub fn status(&self) -> &EntityStatus
The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
Sourcepub fn associated_rule_list(&self) -> &[AssociatedRule]
pub fn associated_rule_list(&self) -> &[AssociatedRule]
The rules associated with the template.
Sourcepub fn update_token(&self) -> Option<&str>
pub fn update_token(&self) -> Option<&str>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn is_snapshot(&self) -> Option<bool>
pub fn is_snapshot(&self) -> Option<bool>
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn has_published_version(&self) -> Option<bool>
pub fn has_published_version(&self) -> Option<bool>
Specifies whether a published version of the resource exists.
Sourcepub fn firewall_type(&self) -> &TemplateFirewallType
pub fn firewall_type(&self) -> &TemplateFirewallType
The firewall type associated with the resource.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The time when the resource was last updated.
Sourceimpl CreateTemplateOutput
impl CreateTemplateOutput
Sourcepub fn builder() -> CreateTemplateOutputBuilder
pub fn builder() -> CreateTemplateOutputBuilder
Creates a new builder-style object to manufacture CreateTemplateOutput.