#[non_exhaustive]pub struct GenerateRuleConfigurationInputBuilder { /* private fields */ }Expand description
A builder for GenerateRuleConfigurationInput.
Implementations
Sourceimpl GenerateRuleConfigurationInputBuilder
impl GenerateRuleConfigurationInputBuilder
Sourcepub fn prompt(self, input: impl Into<String>) -> Self
pub fn prompt(self, input: impl Into<String>) -> Self
A natural-language description of the configuration that you want to generate.
This field is required.Sourcepub fn set_prompt(self, input: Option<String>) -> Self
pub fn set_prompt(self, input: Option<String>) -> Self
A natural-language description of the configuration that you want to generate.
Sourcepub fn get_prompt(&self) -> &Option<String>
pub fn get_prompt(&self) -> &Option<String>
A natural-language description of the configuration that you want to generate.
Sourcepub fn rule_firewall_type(self, input: RuleFirewallType) -> Self
pub fn rule_firewall_type(self, input: RuleFirewallType) -> Self
The firewall type of the rule.
This field is required.Sourcepub fn set_rule_firewall_type(self, input: Option<RuleFirewallType>) -> Self
pub fn set_rule_firewall_type(self, input: Option<RuleFirewallType>) -> Self
The firewall type of the rule.
Sourcepub fn get_rule_firewall_type(&self) -> &Option<RuleFirewallType>
pub fn get_rule_firewall_type(&self) -> &Option<RuleFirewallType>
The firewall type of the rule.
Sourcepub fn rule_type(self, input: RuleType) -> Self
pub fn rule_type(self, input: RuleType) -> Self
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn set_rule_type(self, input: Option<RuleType>) -> Self
pub fn set_rule_type(self, input: Option<RuleType>) -> Self
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn get_rule_type(&self) -> &Option<RuleType>
pub fn get_rule_type(&self) -> &Option<RuleType>
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn waf_config_data_type(self, input: WafConfigDataType) -> Self
pub fn waf_config_data_type(self, input: WafConfigDataType) -> Self
For AWS WAF configuration rules, the specific AWS WAF configuration variant to generate. This is optional; if you omit it, the service selects the variant.
Sourcepub fn set_waf_config_data_type(self, input: Option<WafConfigDataType>) -> Self
pub fn set_waf_config_data_type(self, input: Option<WafConfigDataType>) -> Self
For AWS WAF configuration rules, the specific AWS WAF configuration variant to generate. This is optional; if you omit it, the service selects the variant.
Sourcepub fn get_waf_config_data_type(&self) -> &Option<WafConfigDataType>
pub fn get_waf_config_data_type(&self) -> &Option<WafConfigDataType>
For AWS WAF configuration rules, the specific AWS WAF configuration variant to generate. This is optional; if you omit it, the service selects the variant.
Sourcepub fn current_configuration(self, input: impl Into<String>) -> Self
pub fn current_configuration(self, input: impl Into<String>) -> Self
An existing configuration to edit, as a JSON string. When you provide this value, the operation edits the configuration. When you omit it, the operation generates a new configuration.
Sourcepub fn set_current_configuration(self, input: Option<String>) -> Self
pub fn set_current_configuration(self, input: Option<String>) -> Self
An existing configuration to edit, as a JSON string. When you provide this value, the operation edits the configuration. When you omit it, the operation generates a new configuration.
Sourcepub fn get_current_configuration(&self) -> &Option<String>
pub fn get_current_configuration(&self) -> &Option<String>
An existing configuration to edit, as a JSON string. When you provide this value, the operation edits the configuration. When you omit it, the operation generates a new configuration.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn build(self) -> Result<GenerateRuleConfigurationInput, BuildError>
pub fn build(self) -> Result<GenerateRuleConfigurationInput, BuildError>
Consumes the builder and constructs a GenerateRuleConfigurationInput.
Sourceimpl GenerateRuleConfigurationInputBuilder
impl GenerateRuleConfigurationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GenerateRuleConfigurationOutput, SdkError<GenerateRuleConfigurationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GenerateRuleConfigurationOutput, SdkError<GenerateRuleConfigurationError, HttpResponse>>
Sends a request with this input using the given client.