#[non_exhaustive]pub struct GenerateRuleConfigurationInput {
pub prompt: Option<String>,
pub rule_firewall_type: Option<RuleFirewallType>,
pub rule_type: Option<RuleType>,
pub waf_config_data_type: Option<WafConfigDataType>,
pub current_configuration: Option<String>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.prompt: Option<String>A natural-language description of the configuration that you want to generate.
rule_firewall_type: Option<RuleFirewallType>The firewall type of the rule.
rule_type: Option<RuleType>The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
waf_config_data_type: Option<WafConfigDataType>For AWS WAF configuration rules, the specific AWS WAF configuration variant to generate. This is optional; if you omit it, the service selects the variant.
current_configuration: Option<String>An existing configuration to edit, as a JSON string. When you provide this value, the operation edits the configuration. When you omit it, the operation generates a new configuration.
client_token: Option<String>A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Implementations
Sourceimpl GenerateRuleConfigurationInput
impl GenerateRuleConfigurationInput
Sourcepub fn prompt(&self) -> Option<&str>
pub fn prompt(&self) -> Option<&str>
A natural-language description of the configuration that you want to generate.
Sourcepub fn rule_firewall_type(&self) -> Option<&RuleFirewallType>
pub fn rule_firewall_type(&self) -> Option<&RuleFirewallType>
The firewall type of the rule.
Sourcepub fn rule_type(&self) -> Option<&RuleType>
pub fn rule_type(&self) -> Option<&RuleType>
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn waf_config_data_type(&self) -> Option<&WafConfigDataType>
pub fn waf_config_data_type(&self) -> Option<&WafConfigDataType>
For AWS WAF configuration rules, the specific AWS WAF configuration variant to generate. This is optional; if you omit it, the service selects the variant.
Sourcepub fn current_configuration(&self) -> Option<&str>
pub fn current_configuration(&self) -> Option<&str>
An existing configuration to edit, as a JSON string. When you provide this value, the operation edits the configuration. When you omit it, the operation generates a new configuration.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourceimpl GenerateRuleConfigurationInput
impl GenerateRuleConfigurationInput
Sourcepub fn builder() -> GenerateRuleConfigurationInputBuilder
pub fn builder() -> GenerateRuleConfigurationInputBuilder
Creates a new builder-style object to manufacture GenerateRuleConfigurationInput.