#[non_exhaustive]pub struct GetDeploymentOutputBuilder { /* private fields */ }Expand description
A builder for GetDeploymentOutput.
Implementations
Sourceimpl GetDeploymentOutputBuilder
impl GetDeploymentOutputBuilder
Sourcepub fn deployment_id(self, input: impl Into<String>) -> Self
pub fn deployment_id(self, input: impl Into<String>) -> Self
The service-generated id of the deployment.
This field is required.Sourcepub fn set_deployment_id(self, input: Option<String>) -> Self
pub fn set_deployment_id(self, input: Option<String>) -> Self
The service-generated id of the deployment.
Sourcepub fn get_deployment_id(&self) -> &Option<String>
pub fn get_deployment_id(&self) -> &Option<String>
The service-generated id of the deployment.
Sourcepub fn deployment_arn(self, input: impl Into<String>) -> Self
pub fn deployment_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the deployment.
This field is required.Sourcepub fn set_deployment_arn(self, input: Option<String>) -> Self
pub fn set_deployment_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the deployment.
Sourcepub fn get_deployment_arn(&self) -> &Option<String>
pub fn get_deployment_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the deployment.
Sourcepub fn deployment_name(self, input: impl Into<String>) -> Self
pub fn deployment_name(self, input: impl Into<String>) -> Self
The name of the deployment.
This field is required.Sourcepub fn set_deployment_name(self, input: Option<String>) -> Self
pub fn set_deployment_name(self, input: Option<String>) -> Self
The name of the deployment.
Sourcepub fn get_deployment_name(&self) -> &Option<String>
pub fn get_deployment_name(&self) -> &Option<String>
The name of the deployment.
Sourcepub fn deployment_description(self, input: impl Into<String>) -> Self
pub fn deployment_description(self, input: impl Into<String>) -> Self
A description of the deployment.
Sourcepub fn set_deployment_description(self, input: Option<String>) -> Self
pub fn set_deployment_description(self, input: Option<String>) -> Self
A description of the deployment.
Sourcepub fn get_deployment_description(&self) -> &Option<String>
pub fn get_deployment_description(&self) -> &Option<String>
A description of the deployment.
Sourcepub fn status(self, input: EntityStatus) -> Self
pub fn status(self, input: EntityStatus) -> Self
The current status of the resource: DRAFT (unpublished, editable), ACTIVE (published, in use), or DISABLED (deactivated; changes cannot be published until the resource is re-enabled).
Sourcepub fn set_status(self, input: Option<EntityStatus>) -> Self
pub fn set_status(self, input: Option<EntityStatus>) -> Self
The current status of the resource: DRAFT (unpublished, editable), ACTIVE (published, in use), or DISABLED (deactivated; changes cannot be published until the resource is re-enabled).
Sourcepub fn get_status(&self) -> &Option<EntityStatus>
pub fn get_status(&self) -> &Option<EntityStatus>
The current status of the resource: DRAFT (unpublished, editable), ACTIVE (published, in use), or DISABLED (deactivated; changes cannot be published until the resource is re-enabled).
Sourcepub fn deployment_configuration(self, input: DeploymentConfiguration) -> Self
pub fn deployment_configuration(self, input: DeploymentConfiguration) -> Self
The configuration settings for the deployment.
Sourcepub fn set_deployment_configuration(
self,
input: Option<DeploymentConfiguration>,
) -> Self
pub fn set_deployment_configuration( self, input: Option<DeploymentConfiguration>, ) -> Self
The configuration settings for the deployment.
Sourcepub fn get_deployment_configuration(&self) -> &Option<DeploymentConfiguration>
pub fn get_deployment_configuration(&self) -> &Option<DeploymentConfiguration>
The configuration settings for the deployment.
Sourcepub fn associated_policy_list(self, input: AssociatedPolicy) -> Self
pub fn associated_policy_list(self, input: AssociatedPolicy) -> Self
Appends an item to associated_policy_list.
To override the contents of this collection use set_associated_policy_list.
The policies associated with the deployment.
Sourcepub fn set_associated_policy_list(
self,
input: Option<Vec<AssociatedPolicy>>,
) -> Self
pub fn set_associated_policy_list( self, input: Option<Vec<AssociatedPolicy>>, ) -> Self
The policies associated with the deployment.
Sourcepub fn get_associated_policy_list(&self) -> &Option<Vec<AssociatedPolicy>>
pub fn get_associated_policy_list(&self) -> &Option<Vec<AssociatedPolicy>>
The policies associated with the deployment.
Sourcepub fn associated_scope_list(self, input: AssociatedScope) -> Self
pub fn associated_scope_list(self, input: AssociatedScope) -> Self
Appends an item to associated_scope_list.
To override the contents of this collection use set_associated_scope_list.
The scope associated with the deployment. A deployment has exactly one scope.
Sourcepub fn set_associated_scope_list(
self,
input: Option<Vec<AssociatedScope>>,
) -> Self
pub fn set_associated_scope_list( self, input: Option<Vec<AssociatedScope>>, ) -> Self
The scope associated with the deployment. A deployment has exactly one scope.
Sourcepub fn get_associated_scope_list(&self) -> &Option<Vec<AssociatedScope>>
pub fn get_associated_scope_list(&self) -> &Option<Vec<AssociatedScope>>
The scope associated with the deployment. A deployment has exactly one scope.
Sourcepub fn version(self, input: impl Into<String>) -> Self
pub fn version(self, input: impl Into<String>) -> Self
The version of the resource.
This field is required.Sourcepub fn set_version(self, input: Option<String>) -> Self
pub fn set_version(self, input: Option<String>) -> Self
The version of the resource.
Sourcepub fn get_version(&self) -> &Option<String>
pub fn get_version(&self) -> &Option<String>
The version of the resource.
Sourcepub fn update_token(self, input: impl Into<String>) -> Self
pub fn update_token(self, input: impl Into<String>) -> Self
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn set_update_token(self, input: Option<String>) -> Self
pub fn set_update_token(self, input: Option<String>) -> Self
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn get_update_token(&self) -> &Option<String>
pub fn get_update_token(&self) -> &Option<String>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn is_snapshot(self, input: bool) -> Self
pub fn is_snapshot(self, input: bool) -> Self
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn set_is_snapshot(self, input: Option<bool>) -> Self
pub fn set_is_snapshot(self, input: Option<bool>) -> Self
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn get_is_snapshot(&self) -> &Option<bool>
pub fn get_is_snapshot(&self) -> &Option<bool>
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn has_published_version(self, input: bool) -> Self
pub fn has_published_version(self, input: bool) -> Self
Specifies whether a published version of the resource exists.
Sourcepub fn set_has_published_version(self, input: Option<bool>) -> Self
pub fn set_has_published_version(self, input: Option<bool>) -> Self
Specifies whether a published version of the resource exists.
Sourcepub fn get_has_published_version(&self) -> &Option<bool>
pub fn get_has_published_version(&self) -> &Option<bool>
Specifies whether a published version of the resource exists.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The time when the resource was last updated.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The time when the resource was last updated.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The time when the resource was last updated.
Sourcepub fn deployment_coverage(self, input: DeploymentCoverageEntry) -> Self
pub fn deployment_coverage(self, input: DeploymentCoverageEntry) -> Self
Appends an item to deployment_coverage.
To override the contents of this collection use set_deployment_coverage.
The coverage information for the deployment. For each firewall type, it shows which policies have that firewall type and which in-scope resource types the firewall type protects.
Sourcepub fn set_deployment_coverage(
self,
input: Option<Vec<DeploymentCoverageEntry>>,
) -> Self
pub fn set_deployment_coverage( self, input: Option<Vec<DeploymentCoverageEntry>>, ) -> Self
The coverage information for the deployment. For each firewall type, it shows which policies have that firewall type and which in-scope resource types the firewall type protects.
Sourcepub fn get_deployment_coverage(&self) -> &Option<Vec<DeploymentCoverageEntry>>
pub fn get_deployment_coverage(&self) -> &Option<Vec<DeploymentCoverageEntry>>
The coverage information for the deployment. For each firewall type, it shows which policies have that firewall type and which in-scope resource types the firewall type protects.
Sourcepub fn warnings(self, input: DeploymentWarningEntry) -> Self
pub fn warnings(self, input: DeploymentWarningEntry) -> Self
Appends an item to warnings.
To override the contents of this collection use set_warnings.
Warnings about potential issues, such as a policy that has no applicable resources in the deployment's scope.
Sourcepub fn set_warnings(self, input: Option<Vec<DeploymentWarningEntry>>) -> Self
pub fn set_warnings(self, input: Option<Vec<DeploymentWarningEntry>>) -> Self
Warnings about potential issues, such as a policy that has no applicable resources in the deployment's scope.
Sourcepub fn get_warnings(&self) -> &Option<Vec<DeploymentWarningEntry>>
pub fn get_warnings(&self) -> &Option<Vec<DeploymentWarningEntry>>
Warnings about potential issues, such as a policy that has no applicable resources in the deployment's scope.
Sourcepub fn build(self) -> Result<GetDeploymentOutput, BuildError>
pub fn build(self) -> Result<GetDeploymentOutput, BuildError>
Consumes the builder and constructs a GetDeploymentOutput.
This method will fail if any of the following fields are not set: