GetPolicyOutput

Struct GetPolicyOutput 

#[non_exhaustive]
pub struct GetPolicyOutput {
Show 14 fields pub policy_id: String, pub policy_arn: String, pub policy_name: String, pub policy_description: Option<String>, pub status: EntityStatus, pub priority: i32, pub associated_template_and_rule_list: Vec<AssociatedTemplateOrRule>, pub version: String, pub update_token: Option<String>, pub is_snapshot: Option<bool>, pub has_published_version: Option<bool>, pub firewall_type: PolicyFirewallType, pub policy_configuration: Option<PolicyConfiguration>, pub updated_at: Option<DateTime>, /* private fields */
}

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
policy_id: String

The service-generated id of the policy.

policy_arn: String

The Amazon Resource Name (ARN) of the policy.

policy_name: String

The name of the policy.

policy_description: Option<String>

A description of the policy.

status: EntityStatus

The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).

priority: i32

The priority of the resource. A lower number indicates a higher priority.

associated_template_and_rule_list: Vec<AssociatedTemplateOrRule>

The templates and rules associated with the policy. For AWS WAF policies, this list contains 1 to 100 templates or rules, of which at most 2 can be templates. For AWS Shield Advanced policies, this list is empty.

version: String

The version of the resource.

update_token: Option<String>

A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.

is_snapshot: Option<bool>

Specifies whether the resource is a snapshot of a published version.

has_published_version: Option<bool>

Specifies whether a published version of the resource exists.

firewall_type: PolicyFirewallType

The firewall type associated with the resource.

policy_configuration: Option<PolicyConfiguration>

The configuration settings that control the policy's behavior, including remediation and firewall-type-specific settings.

updated_at: Option<DateTime>

The time when the resource was last updated.

Implementations

Source

impl GetPolicyOutput

pub fn policy_id(&self) -> &str

The service-generated id of the policy.

pub fn policy_arn(&self) -> &str

The Amazon Resource Name (ARN) of the policy.

pub fn policy_name(&self) -> &str

The name of the policy.

pub fn policy_description(&self) -> Option<&str>

A description of the policy.

pub fn status(&self) -> &EntityStatus

The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).

pub fn priority(&self) -> i32

The priority of the resource. A lower number indicates a higher priority.

pub fn associated_template_and_rule_list(&self) -> &[AssociatedTemplateOrRule]

The templates and rules associated with the policy. For AWS WAF policies, this list contains 1 to 100 templates or rules, of which at most 2 can be templates. For AWS Shield Advanced policies, this list is empty.

pub fn version(&self) -> &str

The version of the resource.

pub fn update_token(&self) -> Option<&str>

A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.

pub fn is_snapshot(&self) -> Option<bool>

Specifies whether the resource is a snapshot of a published version.

pub fn has_published_version(&self) -> Option<bool>

Specifies whether a published version of the resource exists.

pub fn firewall_type(&self) -> &PolicyFirewallType

The firewall type associated with the resource.

pub fn policy_configuration(&self) -> Option<&PolicyConfiguration>

The configuration settings that control the policy's behavior, including remediation and firewall-type-specific settings.

pub fn updated_at(&self) -> Option<&DateTime>

The time when the resource was last updated.

Source

impl GetPolicyOutput

pub fn builder() -> GetPolicyOutputBuilder

Creates a new builder-style object to manufacture GetPolicyOutput.