#[non_exhaustive]pub struct GetScopeOutput {
pub scope_id: String,
pub scope_arn: String,
pub scope_name: String,
pub scope_description: Option<String>,
pub scope_configuration: Option<ScopeConfiguration>,
pub status: EntityStatus,
pub version: String,
pub update_token: Option<String>,
pub is_snapshot: Option<bool>,
pub has_published_version: Option<bool>,
pub updated_at: Option<DateTime>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.scope_id: StringThe service-generated id of the scope.
scope_arn: StringThe Amazon Resource Name (ARN) of the scope.
scope_name: StringThe name of the scope.
scope_description: Option<String>A description of the scope.
scope_configuration: Option<ScopeConfiguration>The configuration that defines which accounts and resources are in scope.
status: EntityStatusThe current status of the resource: DRAFT (unpublished, editable), ACTIVE (published, in use), or DISABLED (deactivated; changes cannot be published until the resource is re-enabled).
version: StringThe version of the resource.
update_token: Option<String>A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
is_snapshot: Option<bool>Specifies whether the resource is a snapshot of a published version.
has_published_version: Option<bool>Specifies whether a published version of the resource exists.
updated_at: Option<DateTime>The time when the resource was last updated.
Implementations
Sourceimpl GetScopeOutput
impl GetScopeOutput
Sourcepub fn scope_name(&self) -> &str
pub fn scope_name(&self) -> &str
The name of the scope.
Sourcepub fn scope_description(&self) -> Option<&str>
pub fn scope_description(&self) -> Option<&str>
A description of the scope.
Sourcepub fn scope_configuration(&self) -> Option<&ScopeConfiguration>
pub fn scope_configuration(&self) -> Option<&ScopeConfiguration>
The configuration that defines which accounts and resources are in scope.
Sourcepub fn status(&self) -> &EntityStatus
pub fn status(&self) -> &EntityStatus
The current status of the resource: DRAFT (unpublished, editable), ACTIVE (published, in use), or DISABLED (deactivated; changes cannot be published until the resource is re-enabled).
Sourcepub fn update_token(&self) -> Option<&str>
pub fn update_token(&self) -> Option<&str>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn is_snapshot(&self) -> Option<bool>
pub fn is_snapshot(&self) -> Option<bool>
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn has_published_version(&self) -> Option<bool>
pub fn has_published_version(&self) -> Option<bool>
Specifies whether a published version of the resource exists.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The time when the resource was last updated.
Sourceimpl GetScopeOutput
impl GetScopeOutput
Sourcepub fn builder() -> GetScopeOutputBuilder
pub fn builder() -> GetScopeOutputBuilder
Creates a new builder-style object to manufacture GetScopeOutput.