#[non_exhaustive]pub struct ListScopesInput {
pub max_results: Option<i32>,
pub next_token: Option<String>,
pub status: Option<EntityStatusFilter>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_results: Option<i32>The maximum number of results to return in a single call. Valid range: 1-100. To retrieve the remaining results, use the returned nextToken value in a subsequent call.
next_token: Option<String>The token for the next page of results. To retrieve the next page, call the operation again and provide this value. When there are no more results, this value is null.
status: Option<EntityStatusFilter>Filters the results by status: ACTIVE, DRAFT, or DISABLED.
Implementations
Sourceimpl ListScopesInput
impl ListScopesInput
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return in a single call. Valid range: 1-100. To retrieve the remaining results, use the returned nextToken value in a subsequent call.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The token for the next page of results. To retrieve the next page, call the operation again and provide this value. When there are no more results, this value is null.
Sourcepub fn status(&self) -> Option<&EntityStatusFilter>
pub fn status(&self) -> Option<&EntityStatusFilter>
Filters the results by status: ACTIVE, DRAFT, or DISABLED.
Sourceimpl ListScopesInput
impl ListScopesInput
Sourcepub fn builder() -> ListScopesInputBuilder
pub fn builder() -> ListScopesInputBuilder
Creates a new builder-style object to manufacture ListScopesInput.