#[non_exhaustive]pub struct ListScopesOutput {
pub next_token: Option<String>,
pub scopes: Vec<ScopeSummary>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>The token for the next page of results. To retrieve the next page, call the operation again and provide this value. When there are no more results, this value is null.
scopes: Vec<ScopeSummary>The list of scopes.
Implementations
Sourceimpl ListScopesOutput
impl ListScopesOutput
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The token for the next page of results. To retrieve the next page, call the operation again and provide this value. When there are no more results, this value is null.
Sourcepub fn scopes(&self) -> &[ScopeSummary]
pub fn scopes(&self) -> &[ScopeSummary]
The list of scopes.
Sourceimpl ListScopesOutput
impl ListScopesOutput
Sourcepub fn builder() -> ListScopesOutputBuilder
pub fn builder() -> ListScopesOutputBuilder
Creates a new builder-style object to manufacture ListScopesOutput.