pub struct UpdateDeploymentFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateDeployment.
Updates the specified deployment. To prevent conflicting concurrent updates, provide the current updateToken. Use isPublished to publish the update or keep the deployment as a draft.
Implementations
Sourceimpl UpdateDeploymentFluentBuilder
impl UpdateDeploymentFluentBuilder
Sourcepub fn as_input(&self) -> &UpdateDeploymentInputBuilder
pub fn as_input(&self) -> &UpdateDeploymentInputBuilder
Access the UpdateDeployment as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateDeploymentOutput, SdkError<UpdateDeploymentError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateDeploymentOutput, SdkError<UpdateDeploymentError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateDeploymentOutput, UpdateDeploymentError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateDeploymentOutput, UpdateDeploymentError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn deployment_identifier(self, input: impl Into<String>) -> Self
pub fn deployment_identifier(self, input: impl Into<String>) -> Self
The identifier of the deployment. This is the deployment's Amazon Resource Name (ARN).
Sourcepub fn set_deployment_identifier(self, input: Option<String>) -> Self
pub fn set_deployment_identifier(self, input: Option<String>) -> Self
The identifier of the deployment. This is the deployment's Amazon Resource Name (ARN).
Sourcepub fn get_deployment_identifier(&self) -> &Option<String>
pub fn get_deployment_identifier(&self) -> &Option<String>
The identifier of the deployment. This is the deployment's Amazon Resource Name (ARN).
Sourcepub fn update_token(self, input: impl Into<String>) -> Self
pub fn update_token(self, input: impl Into<String>) -> Self
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn set_update_token(self, input: Option<String>) -> Self
pub fn set_update_token(self, input: Option<String>) -> Self
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn get_update_token(&self) -> &Option<String>
pub fn get_update_token(&self) -> &Option<String>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn deployment_description(self, input: impl Into<String>) -> Self
pub fn deployment_description(self, input: impl Into<String>) -> Self
A description of the deployment.
Sourcepub fn set_deployment_description(self, input: Option<String>) -> Self
pub fn set_deployment_description(self, input: Option<String>) -> Self
A description of the deployment.
Sourcepub fn get_deployment_description(&self) -> &Option<String>
pub fn get_deployment_description(&self) -> &Option<String>
A description of the deployment.
Sourcepub fn deployment_configuration(self, input: DeploymentConfiguration) -> Self
pub fn deployment_configuration(self, input: DeploymentConfiguration) -> Self
The configuration settings for the deployment.
Sourcepub fn set_deployment_configuration(
self,
input: Option<DeploymentConfiguration>,
) -> Self
pub fn set_deployment_configuration( self, input: Option<DeploymentConfiguration>, ) -> Self
The configuration settings for the deployment.
Sourcepub fn get_deployment_configuration(&self) -> &Option<DeploymentConfiguration>
pub fn get_deployment_configuration(&self) -> &Option<DeploymentConfiguration>
The configuration settings for the deployment.
Sourcepub fn associated_policy_list(self, input: PolicyReference) -> Self
pub fn associated_policy_list(self, input: PolicyReference) -> Self
Appends an item to associatedPolicyList.
To override the contents of this collection use set_associated_policy_list.
The policies associated with the deployment.
Sourcepub fn set_associated_policy_list(
self,
input: Option<Vec<PolicyReference>>,
) -> Self
pub fn set_associated_policy_list( self, input: Option<Vec<PolicyReference>>, ) -> Self
The policies associated with the deployment.
Sourcepub fn get_associated_policy_list(&self) -> &Option<Vec<PolicyReference>>
pub fn get_associated_policy_list(&self) -> &Option<Vec<PolicyReference>>
The policies associated with the deployment.
Sourcepub fn associated_scope_list(self, input: ScopeReference) -> Self
pub fn associated_scope_list(self, input: ScopeReference) -> Self
Appends an item to associatedScopeList.
To override the contents of this collection use set_associated_scope_list.
The scope associated with the deployment. A deployment has exactly one scope.
Sourcepub fn set_associated_scope_list(
self,
input: Option<Vec<ScopeReference>>,
) -> Self
pub fn set_associated_scope_list( self, input: Option<Vec<ScopeReference>>, ) -> Self
The scope associated with the deployment. A deployment has exactly one scope.
Sourcepub fn get_associated_scope_list(&self) -> &Option<Vec<ScopeReference>>
pub fn get_associated_scope_list(&self) -> &Option<Vec<ScopeReference>>
The scope associated with the deployment. A deployment has exactly one scope.
Sourcepub fn is_published(self, input: bool) -> Self
pub fn is_published(self, input: bool) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
Sourcepub fn set_is_published(self, input: Option<bool>) -> Self
pub fn set_is_published(self, input: Option<bool>) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
Sourcepub fn get_is_published(&self) -> &Option<bool>
pub fn get_is_published(&self) -> &Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.