#[non_exhaustive]pub struct UpdatePolicyInput {
pub policy_identifier: Option<String>,
pub update_token: Option<String>,
pub policy_description: Option<String>,
pub priority: Option<i32>,
pub associated_template_and_rule_list: Option<Vec<TemplateOrRuleReference>>,
pub policy_configuration: Option<PolicyConfiguration>,
pub is_published: Option<bool>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.policy_identifier: Option<String>The identifier of the policy. This is the policy's Amazon Resource Name (ARN).
update_token: Option<String>A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
policy_description: Option<String>A description of the policy.
priority: Option<i32>The priority of the resource. A lower number indicates a higher priority.
associated_template_and_rule_list: Option<Vec<TemplateOrRuleReference>>The templates and rules to associate with the policy. For AWS WAF policies, specify 1 to 100 templates or rules, of which at most 2 can be templates. For AWS Shield Advanced policies, this list must be empty.
policy_configuration: Option<PolicyConfiguration>The configuration settings that control the policy's behavior, including remediation and firewall-type-specific settings.
is_published: Option<bool>Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
client_token: Option<String>A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Implementations
Sourceimpl UpdatePolicyInput
impl UpdatePolicyInput
Sourcepub fn policy_identifier(&self) -> Option<&str>
pub fn policy_identifier(&self) -> Option<&str>
The identifier of the policy. This is the policy's Amazon Resource Name (ARN).
Sourcepub fn update_token(&self) -> Option<&str>
pub fn update_token(&self) -> Option<&str>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn policy_description(&self) -> Option<&str>
pub fn policy_description(&self) -> Option<&str>
A description of the policy.
Sourcepub fn priority(&self) -> Option<i32>
pub fn priority(&self) -> Option<i32>
The priority of the resource. A lower number indicates a higher priority.
Sourcepub fn associated_template_and_rule_list(&self) -> &[TemplateOrRuleReference]
pub fn associated_template_and_rule_list(&self) -> &[TemplateOrRuleReference]
The templates and rules to associate with the policy. For AWS WAF policies, specify 1 to 100 templates or rules, of which at most 2 can be templates. For AWS Shield Advanced policies, this list must be empty.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .associated_template_and_rule_list.is_none().
Sourcepub fn policy_configuration(&self) -> Option<&PolicyConfiguration>
pub fn policy_configuration(&self) -> Option<&PolicyConfiguration>
The configuration settings that control the policy's behavior, including remediation and firewall-type-specific settings.
Sourcepub fn is_published(&self) -> Option<bool>
pub fn is_published(&self) -> Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourceimpl UpdatePolicyInput
impl UpdatePolicyInput
Sourcepub fn builder() -> UpdatePolicyInputBuilder
pub fn builder() -> UpdatePolicyInputBuilder
Creates a new builder-style object to manufacture UpdatePolicyInput.