#[non_exhaustive]pub struct UpdateRuleInputBuilder { /* private fields */ }Expand description
A builder for UpdateRuleInput.
Implementations
Sourceimpl UpdateRuleInputBuilder
impl UpdateRuleInputBuilder
Sourcepub fn rule_identifier(self, input: impl Into<String>) -> Self
pub fn rule_identifier(self, input: impl Into<String>) -> Self
The identifier of the rule. This is the rule's Amazon Resource Name (ARN).
This field is required.Sourcepub fn set_rule_identifier(self, input: Option<String>) -> Self
pub fn set_rule_identifier(self, input: Option<String>) -> Self
The identifier of the rule. This is the rule's Amazon Resource Name (ARN).
Sourcepub fn get_rule_identifier(&self) -> &Option<String>
pub fn get_rule_identifier(&self) -> &Option<String>
The identifier of the rule. This is the rule's Amazon Resource Name (ARN).
Sourcepub fn update_token(self, input: impl Into<String>) -> Self
pub fn update_token(self, input: impl Into<String>) -> Self
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn set_update_token(self, input: Option<String>) -> Self
pub fn set_update_token(self, input: Option<String>) -> Self
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn get_update_token(&self) -> &Option<String>
pub fn get_update_token(&self) -> &Option<String>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn rule_type(self, input: RuleType) -> Self
pub fn rule_type(self, input: RuleType) -> Self
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn set_rule_type(self, input: Option<RuleType>) -> Self
pub fn set_rule_type(self, input: Option<RuleType>) -> Self
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn get_rule_type(&self) -> &Option<RuleType>
pub fn get_rule_type(&self) -> &Option<RuleType>
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn rule_description(self, input: impl Into<String>) -> Self
pub fn rule_description(self, input: impl Into<String>) -> Self
A description of the rule.
Sourcepub fn set_rule_description(self, input: Option<String>) -> Self
pub fn set_rule_description(self, input: Option<String>) -> Self
A description of the rule.
Sourcepub fn get_rule_description(&self) -> &Option<String>
pub fn get_rule_description(&self) -> &Option<String>
A description of the rule.
Sourcepub fn configuration(self, input: Document) -> Self
pub fn configuration(self, input: Document) -> Self
The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type. For an AWS WAF INSPECTION rule, provide an AWS WAF rule group. For an AWS WAF CONFIGURATION rule, provide a single web ACL setting, such as DefaultAction or VisibilityConfig; use wafConfigDataType to declare which setting the document contains. For the schema of each setting and complete examples, see Writing rule configurations in the AWS Network Security Manager Developer Guide.
Sourcepub fn set_configuration(self, input: Option<Document>) -> Self
pub fn set_configuration(self, input: Option<Document>) -> Self
The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type. For an AWS WAF INSPECTION rule, provide an AWS WAF rule group. For an AWS WAF CONFIGURATION rule, provide a single web ACL setting, such as DefaultAction or VisibilityConfig; use wafConfigDataType to declare which setting the document contains. For the schema of each setting and complete examples, see Writing rule configurations in the AWS Network Security Manager Developer Guide.
Sourcepub fn get_configuration(&self) -> &Option<Document>
pub fn get_configuration(&self) -> &Option<Document>
The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type. For an AWS WAF INSPECTION rule, provide an AWS WAF rule group. For an AWS WAF CONFIGURATION rule, provide a single web ACL setting, such as DefaultAction or VisibilityConfig; use wafConfigDataType to declare which setting the document contains. For the schema of each setting and complete examples, see Writing rule configurations in the AWS Network Security Manager Developer Guide.
Sourcepub fn is_published(self, input: bool) -> Self
pub fn is_published(self, input: bool) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
Sourcepub fn set_is_published(self, input: Option<bool>) -> Self
pub fn set_is_published(self, input: Option<bool>) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
Sourcepub fn get_is_published(&self) -> &Option<bool>
pub fn get_is_published(&self) -> &Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn build(self) -> Result<UpdateRuleInput, BuildError>
pub fn build(self) -> Result<UpdateRuleInput, BuildError>
Consumes the builder and constructs a UpdateRuleInput.
Sourceimpl UpdateRuleInputBuilder
impl UpdateRuleInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateRuleOutput, SdkError<UpdateRuleError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateRuleOutput, SdkError<UpdateRuleError, HttpResponse>>
Sends a request with this input using the given client.