#[non_exhaustive]pub struct UpdateRuleInput {
pub rule_identifier: Option<String>,
pub update_token: Option<String>,
pub rule_type: Option<RuleType>,
pub rule_description: Option<String>,
pub configuration: Option<Document>,
pub is_published: Option<bool>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rule_identifier: Option<String>The identifier of the rule. This is the rule's Amazon Resource Name (ARN).
update_token: Option<String>A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
rule_type: Option<RuleType>The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
rule_description: Option<String>A description of the rule.
configuration: Option<Document>The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type. For an AWS WAF INSPECTION rule, provide an AWS WAF rule group. For an AWS WAF CONFIGURATION rule, provide a single web ACL setting, such as DefaultAction or VisibilityConfig; use wafConfigDataType to declare which setting the document contains. For the schema of each setting and complete examples, see Writing rule configurations in the AWS Network Security Manager Developer Guide.
is_published: Option<bool>Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
client_token: Option<String>A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Implementations
Sourceimpl UpdateRuleInput
impl UpdateRuleInput
Sourcepub fn rule_identifier(&self) -> Option<&str>
pub fn rule_identifier(&self) -> Option<&str>
The identifier of the rule. This is the rule's Amazon Resource Name (ARN).
Sourcepub fn update_token(&self) -> Option<&str>
pub fn update_token(&self) -> Option<&str>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn rule_type(&self) -> Option<&RuleType>
pub fn rule_type(&self) -> Option<&RuleType>
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn rule_description(&self) -> Option<&str>
pub fn rule_description(&self) -> Option<&str>
A description of the rule.
Sourcepub fn configuration(&self) -> Option<&Document>
pub fn configuration(&self) -> Option<&Document>
The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type. For an AWS WAF INSPECTION rule, provide an AWS WAF rule group. For an AWS WAF CONFIGURATION rule, provide a single web ACL setting, such as DefaultAction or VisibilityConfig; use wafConfigDataType to declare which setting the document contains. For the schema of each setting and complete examples, see Writing rule configurations in the AWS Network Security Manager Developer Guide.
Sourcepub fn is_published(&self) -> Option<bool>
pub fn is_published(&self) -> Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourceimpl UpdateRuleInput
impl UpdateRuleInput
Sourcepub fn builder() -> UpdateRuleInputBuilder
pub fn builder() -> UpdateRuleInputBuilder
Creates a new builder-style object to manufacture UpdateRuleInput.