#[non_exhaustive]pub struct UpdateRuleOutput {Show 13 fields
pub rule_id: String,
pub rule_arn: String,
pub rule_name: String,
pub firewall_type: RuleFirewallType,
pub rule_type: Option<RuleType>,
pub rule_description: Option<String>,
pub configuration: Document,
pub status: EntityStatus,
pub version: String,
pub update_token: Option<String>,
pub is_snapshot: Option<bool>,
pub has_published_version: Option<bool>,
pub updated_at: Option<DateTime>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rule_id: StringThe service-generated id of the rule.
rule_arn: StringThe Amazon Resource Name (ARN) of the rule.
rule_name: StringThe name of the rule.
firewall_type: RuleFirewallTypeThe firewall type associated with the resource.
rule_type: Option<RuleType>The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
rule_description: Option<String>A description of the rule.
configuration: DocumentThe firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type.
status: EntityStatusThe current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
version: StringThe version of the resource.
update_token: Option<String>A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
is_snapshot: Option<bool>Specifies whether the resource is a snapshot of a published version.
has_published_version: Option<bool>Specifies whether a published version of the resource exists.
updated_at: Option<DateTime>The time when the resource was last updated.
Implementations
Sourceimpl UpdateRuleOutput
impl UpdateRuleOutput
Sourcepub fn firewall_type(&self) -> &RuleFirewallType
pub fn firewall_type(&self) -> &RuleFirewallType
The firewall type associated with the resource.
Sourcepub fn rule_type(&self) -> Option<&RuleType>
pub fn rule_type(&self) -> Option<&RuleType>
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn rule_description(&self) -> Option<&str>
pub fn rule_description(&self) -> Option<&str>
A description of the rule.
Sourcepub fn configuration(&self) -> &Document
pub fn configuration(&self) -> &Document
The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type.
Sourcepub fn status(&self) -> &EntityStatus
pub fn status(&self) -> &EntityStatus
The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
Sourcepub fn update_token(&self) -> Option<&str>
pub fn update_token(&self) -> Option<&str>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn is_snapshot(&self) -> Option<bool>
pub fn is_snapshot(&self) -> Option<bool>
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn has_published_version(&self) -> Option<bool>
pub fn has_published_version(&self) -> Option<bool>
Specifies whether a published version of the resource exists.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The time when the resource was last updated.
Sourceimpl UpdateRuleOutput
impl UpdateRuleOutput
Sourcepub fn builder() -> UpdateRuleOutputBuilder
pub fn builder() -> UpdateRuleOutputBuilder
Creates a new builder-style object to manufacture UpdateRuleOutput.