#[non_exhaustive]pub struct UpdateScopeOutputBuilder { /* private fields */ }Expand description
A builder for UpdateScopeOutput.
Implementations
Sourceimpl UpdateScopeOutputBuilder
impl UpdateScopeOutputBuilder
Sourcepub fn scope_id(self, input: impl Into<String>) -> Self
pub fn scope_id(self, input: impl Into<String>) -> Self
The service-generated id of the scope.
This field is required.Sourcepub fn set_scope_id(self, input: Option<String>) -> Self
pub fn set_scope_id(self, input: Option<String>) -> Self
The service-generated id of the scope.
Sourcepub fn get_scope_id(&self) -> &Option<String>
pub fn get_scope_id(&self) -> &Option<String>
The service-generated id of the scope.
Sourcepub fn scope_arn(self, input: impl Into<String>) -> Self
pub fn scope_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the scope.
This field is required.Sourcepub fn set_scope_arn(self, input: Option<String>) -> Self
pub fn set_scope_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the scope.
Sourcepub fn get_scope_arn(&self) -> &Option<String>
pub fn get_scope_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the scope.
Sourcepub fn scope_name(self, input: impl Into<String>) -> Self
pub fn scope_name(self, input: impl Into<String>) -> Self
The name of the scope.
This field is required.Sourcepub fn set_scope_name(self, input: Option<String>) -> Self
pub fn set_scope_name(self, input: Option<String>) -> Self
The name of the scope.
Sourcepub fn get_scope_name(&self) -> &Option<String>
pub fn get_scope_name(&self) -> &Option<String>
The name of the scope.
Sourcepub fn scope_description(self, input: impl Into<String>) -> Self
pub fn scope_description(self, input: impl Into<String>) -> Self
A description of the scope.
Sourcepub fn set_scope_description(self, input: Option<String>) -> Self
pub fn set_scope_description(self, input: Option<String>) -> Self
A description of the scope.
Sourcepub fn get_scope_description(&self) -> &Option<String>
pub fn get_scope_description(&self) -> &Option<String>
A description of the scope.
Sourcepub fn scope_configuration(self, input: ScopeConfiguration) -> Self
pub fn scope_configuration(self, input: ScopeConfiguration) -> Self
The configuration that defines which accounts and resources are in scope.
Sourcepub fn set_scope_configuration(self, input: Option<ScopeConfiguration>) -> Self
pub fn set_scope_configuration(self, input: Option<ScopeConfiguration>) -> Self
The configuration that defines which accounts and resources are in scope.
Sourcepub fn get_scope_configuration(&self) -> &Option<ScopeConfiguration>
pub fn get_scope_configuration(&self) -> &Option<ScopeConfiguration>
The configuration that defines which accounts and resources are in scope.
Sourcepub fn status(self, input: EntityStatus) -> Self
pub fn status(self, input: EntityStatus) -> Self
The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
Sourcepub fn set_status(self, input: Option<EntityStatus>) -> Self
pub fn set_status(self, input: Option<EntityStatus>) -> Self
The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
Sourcepub fn get_status(&self) -> &Option<EntityStatus>
pub fn get_status(&self) -> &Option<EntityStatus>
The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
Sourcepub fn version(self, input: impl Into<String>) -> Self
pub fn version(self, input: impl Into<String>) -> Self
The version of the resource.
This field is required.Sourcepub fn set_version(self, input: Option<String>) -> Self
pub fn set_version(self, input: Option<String>) -> Self
The version of the resource.
Sourcepub fn get_version(&self) -> &Option<String>
pub fn get_version(&self) -> &Option<String>
The version of the resource.
Sourcepub fn update_token(self, input: impl Into<String>) -> Self
pub fn update_token(self, input: impl Into<String>) -> Self
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn set_update_token(self, input: Option<String>) -> Self
pub fn set_update_token(self, input: Option<String>) -> Self
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn get_update_token(&self) -> &Option<String>
pub fn get_update_token(&self) -> &Option<String>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn is_snapshot(self, input: bool) -> Self
pub fn is_snapshot(self, input: bool) -> Self
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn set_is_snapshot(self, input: Option<bool>) -> Self
pub fn set_is_snapshot(self, input: Option<bool>) -> Self
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn get_is_snapshot(&self) -> &Option<bool>
pub fn get_is_snapshot(&self) -> &Option<bool>
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn has_published_version(self, input: bool) -> Self
pub fn has_published_version(self, input: bool) -> Self
Specifies whether a published version of the resource exists.
Sourcepub fn set_has_published_version(self, input: Option<bool>) -> Self
pub fn set_has_published_version(self, input: Option<bool>) -> Self
Specifies whether a published version of the resource exists.
Sourcepub fn get_has_published_version(&self) -> &Option<bool>
pub fn get_has_published_version(&self) -> &Option<bool>
Specifies whether a published version of the resource exists.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The time when the resource was last updated.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The time when the resource was last updated.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The time when the resource was last updated.
Sourcepub fn build(self) -> Result<UpdateScopeOutput, BuildError>
pub fn build(self) -> Result<UpdateScopeOutput, BuildError>
Consumes the builder and constructs a UpdateScopeOutput.
This method will fail if any of the following fields are not set: