#[non_exhaustive]pub struct UpdateScopeInput {
pub scope_identifier: Option<String>,
pub update_token: Option<String>,
pub scope_description: Option<String>,
pub scope_configuration: Option<ScopeConfiguration>,
pub is_published: Option<bool>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.scope_identifier: Option<String>The identifier of the scope. This is the scope's Amazon Resource Name (ARN).
update_token: Option<String>A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
scope_description: Option<String>A description of the scope.
scope_configuration: Option<ScopeConfiguration>The configuration that defines which accounts and resources are in scope. If you don't include this member, the scope keeps its existing configuration.
A new configuration can change which accounts and resources are selected, but it can't add or remove the account filter itself: a scope created for multi-account use stays multi-account, and a scope created for single-account use stays single-account.
is_published: Option<bool>Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
client_token: Option<String>A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Implementations
Sourceimpl UpdateScopeInput
impl UpdateScopeInput
Sourcepub fn scope_identifier(&self) -> Option<&str>
pub fn scope_identifier(&self) -> Option<&str>
The identifier of the scope. This is the scope's Amazon Resource Name (ARN).
Sourcepub fn update_token(&self) -> Option<&str>
pub fn update_token(&self) -> Option<&str>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn scope_description(&self) -> Option<&str>
pub fn scope_description(&self) -> Option<&str>
A description of the scope.
Sourcepub fn scope_configuration(&self) -> Option<&ScopeConfiguration>
pub fn scope_configuration(&self) -> Option<&ScopeConfiguration>
The configuration that defines which accounts and resources are in scope. If you don't include this member, the scope keeps its existing configuration.
A new configuration can change which accounts and resources are selected, but it can't add or remove the account filter itself: a scope created for multi-account use stays multi-account, and a scope created for single-account use stays single-account.
Sourcepub fn is_published(&self) -> Option<bool>
pub fn is_published(&self) -> Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourceimpl UpdateScopeInput
impl UpdateScopeInput
Sourcepub fn builder() -> UpdateScopeInputBuilder
pub fn builder() -> UpdateScopeInputBuilder
Creates a new builder-style object to manufacture UpdateScopeInput.