#[non_exhaustive]pub struct UpdateTemplateInputBuilder { /* private fields */ }Expand description
A builder for UpdateTemplateInput.
Implementations
Sourceimpl UpdateTemplateInputBuilder
impl UpdateTemplateInputBuilder
Sourcepub fn template_identifier(self, input: impl Into<String>) -> Self
pub fn template_identifier(self, input: impl Into<String>) -> Self
The identifier of the template. This is the template's Amazon Resource Name (ARN).
This field is required.Sourcepub fn set_template_identifier(self, input: Option<String>) -> Self
pub fn set_template_identifier(self, input: Option<String>) -> Self
The identifier of the template. This is the template's Amazon Resource Name (ARN).
Sourcepub fn get_template_identifier(&self) -> &Option<String>
pub fn get_template_identifier(&self) -> &Option<String>
The identifier of the template. This is the template's Amazon Resource Name (ARN).
Sourcepub fn update_token(self, input: impl Into<String>) -> Self
pub fn update_token(self, input: impl Into<String>) -> Self
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn set_update_token(self, input: Option<String>) -> Self
pub fn set_update_token(self, input: Option<String>) -> Self
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn get_update_token(&self) -> &Option<String>
pub fn get_update_token(&self) -> &Option<String>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn template_description(self, input: impl Into<String>) -> Self
pub fn template_description(self, input: impl Into<String>) -> Self
A description of the template.
Sourcepub fn set_template_description(self, input: Option<String>) -> Self
pub fn set_template_description(self, input: Option<String>) -> Self
A description of the template.
Sourcepub fn get_template_description(&self) -> &Option<String>
pub fn get_template_description(&self) -> &Option<String>
A description of the template.
Sourcepub fn associated_rule_list(self, input: RuleReference) -> Self
pub fn associated_rule_list(self, input: RuleReference) -> Self
Appends an item to associated_rule_list.
To override the contents of this collection use set_associated_rule_list.
The rules associated with the template.
Sourcepub fn set_associated_rule_list(self, input: Option<Vec<RuleReference>>) -> Self
pub fn set_associated_rule_list(self, input: Option<Vec<RuleReference>>) -> Self
The rules associated with the template.
Sourcepub fn get_associated_rule_list(&self) -> &Option<Vec<RuleReference>>
pub fn get_associated_rule_list(&self) -> &Option<Vec<RuleReference>>
The rules associated with the template.
Sourcepub fn is_published(self, input: bool) -> Self
pub fn is_published(self, input: bool) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
Sourcepub fn set_is_published(self, input: Option<bool>) -> Self
pub fn set_is_published(self, input: Option<bool>) -> Self
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
Sourcepub fn get_is_published(&self) -> &Option<bool>
pub fn get_is_published(&self) -> &Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourcepub fn build(self) -> Result<UpdateTemplateInput, BuildError>
pub fn build(self) -> Result<UpdateTemplateInput, BuildError>
Consumes the builder and constructs a UpdateTemplateInput.
Sourceimpl UpdateTemplateInputBuilder
impl UpdateTemplateInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateTemplateOutput, SdkError<UpdateTemplateError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateTemplateOutput, SdkError<UpdateTemplateError, HttpResponse>>
Sends a request with this input using the given client.