#[non_exhaustive]pub struct UpdateTemplateInput {
pub template_identifier: Option<String>,
pub update_token: Option<String>,
pub template_description: Option<String>,
pub associated_rule_list: Option<Vec<RuleReference>>,
pub is_published: Option<bool>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.template_identifier: Option<String>The identifier of the template. This is the template's Amazon Resource Name (ARN).
update_token: Option<String>A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
template_description: Option<String>A description of the template.
associated_rule_list: Option<Vec<RuleReference>>The rules associated with the template.
is_published: Option<bool>Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
client_token: Option<String>A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Implementations
Sourceimpl UpdateTemplateInput
impl UpdateTemplateInput
Sourcepub fn template_identifier(&self) -> Option<&str>
pub fn template_identifier(&self) -> Option<&str>
The identifier of the template. This is the template's Amazon Resource Name (ARN).
Sourcepub fn update_token(&self) -> Option<&str>
pub fn update_token(&self) -> Option<&str>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn template_description(&self) -> Option<&str>
pub fn template_description(&self) -> Option<&str>
A description of the template.
Sourcepub fn associated_rule_list(&self) -> &[RuleReference]
pub fn associated_rule_list(&self) -> &[RuleReference]
The rules associated with the template.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .associated_rule_list.is_none().
Sourcepub fn is_published(&self) -> Option<bool>
pub fn is_published(&self) -> Option<bool>
Specifies whether to publish the resource. When true, the resource is saved in published (ACTIVE) state. When false, it is saved as a draft (DRAFT).
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive token that you provide to ensure that the operation completes no more than one time. If you retry a request with the same client token and the same parameters, the service returns the result of the original successful request.
Sourceimpl UpdateTemplateInput
impl UpdateTemplateInput
Sourcepub fn builder() -> UpdateTemplateInputBuilder
pub fn builder() -> UpdateTemplateInputBuilder
Creates a new builder-style object to manufacture UpdateTemplateInput.