Client

Struct Client 

pub struct Client { /* private fields */ }
Client for AWS Network Security Manager Customer API

Client for invoking operations on AWS Network Security Manager Customer API. Each operation on AWS Network Security Manager Customer API is a method on this this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.

Constructing a Client

A Config is required to construct a client. For most use cases, the aws-config crate should be used to automatically resolve this config using aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared across multiple different AWS SDK clients. This config resolution process can be customized by calling aws_config::from_env() instead, which returns a ConfigLoader that uses the builder pattern to customize the default config.

In the simplest case, creating a client looks as follows:

let config = aws_config::load_from_env().await;
let client = aws_sdk_networksecuritymanager::Client::new(&config);

Occasionally, SDKs may have additional service-specific values that can be set on the Config that is absent from SdkConfig, or slightly different settings for a specific client may be desired. The Builder struct implements From<&SdkConfig>, so setting these specific settings can be done as follows:

let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_networksecuritymanager::config::Builder::from(&sdk_config)
    .some_service_specific_setting("value")
    .build();

See the aws-config docs and Config for more information on customizing configuration.

Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.

Using the Client

A client has a function for every operation that can be performed by the service. For example, the CreateDeployment operation has a Client::create_deployment, function which returns a builder for that operation. The fluent builder ultimately has a send() function that returns an async future that returns a result, as illustrated below:

ⓘ
let result = client.create_deployment()
    .client_token("example")
    .send()
    .await;

The underlying HTTP requests that get made by this can be modified with the customize_operation function on the fluent builder. See the customize module for more information.

Implementations

Source

impl Client

pub fn create_deployment(&self) -> CreateDeploymentFluentBuilder

Constructs a fluent builder for the CreateDeployment operation.

Source

impl Client

pub fn create_deployment_snapshot( &self, ) -> CreateDeploymentSnapshotFluentBuilder

Constructs a fluent builder for the CreateDeploymentSnapshot operation.

Source

impl Client

pub fn create_policy(&self) -> CreatePolicyFluentBuilder

Constructs a fluent builder for the CreatePolicy operation.

Source

impl Client

pub fn create_policy_snapshot(&self) -> CreatePolicySnapshotFluentBuilder

Constructs a fluent builder for the CreatePolicySnapshot operation.

Source

impl Client

pub fn create_rule(&self) -> CreateRuleFluentBuilder

Constructs a fluent builder for the CreateRule operation.

Source

impl Client

pub fn create_rule_snapshot(&self) -> CreateRuleSnapshotFluentBuilder

Constructs a fluent builder for the CreateRuleSnapshot operation.

Source

impl Client

pub fn create_scope(&self) -> CreateScopeFluentBuilder

Constructs a fluent builder for the CreateScope operation.

Source

impl Client

pub fn create_scope_snapshot(&self) -> CreateScopeSnapshotFluentBuilder

Constructs a fluent builder for the CreateScopeSnapshot operation.

Source

impl Client

pub fn create_template(&self) -> CreateTemplateFluentBuilder

Constructs a fluent builder for the CreateTemplate operation.

Source

impl Client

pub fn create_template_snapshot(&self) -> CreateTemplateSnapshotFluentBuilder

Constructs a fluent builder for the CreateTemplateSnapshot operation.

Source

impl Client

pub fn delete_admin_account(&self) -> DeleteAdminAccountFluentBuilder

Constructs a fluent builder for the DeleteAdminAccount operation.

Source

impl Client

pub fn delete_deployment(&self) -> DeleteDeploymentFluentBuilder

Constructs a fluent builder for the DeleteDeployment operation.

Source

impl Client

pub fn delete_policy(&self) -> DeletePolicyFluentBuilder

Constructs a fluent builder for the DeletePolicy operation.

Source

impl Client

pub fn delete_rule(&self) -> DeleteRuleFluentBuilder

Constructs a fluent builder for the DeleteRule operation.

Source

impl Client

pub fn delete_scope(&self) -> DeleteScopeFluentBuilder

Constructs a fluent builder for the DeleteScope operation.

Source

impl Client

pub fn delete_template(&self) -> DeleteTemplateFluentBuilder

Constructs a fluent builder for the DeleteTemplate operation.

Source

impl Client

pub fn generate_rule_configuration( &self, ) -> GenerateRuleConfigurationFluentBuilder

Constructs a fluent builder for the GenerateRuleConfiguration operation.

Source

impl Client

pub fn get_admin_account(&self) -> GetAdminAccountFluentBuilder

Constructs a fluent builder for the GetAdminAccount operation.

Source

impl Client

pub fn get_deployment(&self) -> GetDeploymentFluentBuilder

Constructs a fluent builder for the GetDeployment operation.

Source

impl Client

pub fn get_policy(&self) -> GetPolicyFluentBuilder

Constructs a fluent builder for the GetPolicy operation.

Source

impl Client

pub fn get_rule(&self) -> GetRuleFluentBuilder

Constructs a fluent builder for the GetRule operation.

Source

impl Client

pub fn get_scope(&self) -> GetScopeFluentBuilder

Constructs a fluent builder for the GetScope operation.

Source

impl Client

pub fn get_template(&self) -> GetTemplateFluentBuilder

Constructs a fluent builder for the GetTemplate operation.

Source

impl Client

pub fn list_admin_accounts(&self) -> ListAdminAccountsFluentBuilder

Constructs a fluent builder for the ListAdminAccounts operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_aggregate_resource_synchronization_statuses( &self, ) -> ListAggregateResourceSynchronizationStatusesFluentBuilder

Constructs a fluent builder for the ListAggregateResourceSynchronizationStatuses operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_deployment_snapshots(&self) -> ListDeploymentSnapshotsFluentBuilder

Constructs a fluent builder for the ListDeploymentSnapshots operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_deployments(&self) -> ListDeploymentsFluentBuilder

Constructs a fluent builder for the ListDeployments operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_policies(&self) -> ListPoliciesFluentBuilder

Constructs a fluent builder for the ListPolicies operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_policy_snapshots(&self) -> ListPolicySnapshotsFluentBuilder

Constructs a fluent builder for the ListPolicySnapshots operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_resource_associations( &self, ) -> ListResourceAssociationsFluentBuilder

Constructs a fluent builder for the ListResourceAssociations operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_resource_synchronization_statuses( &self, ) -> ListResourceSynchronizationStatusesFluentBuilder

Constructs a fluent builder for the ListResourceSynchronizationStatuses operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_rule_snapshots(&self) -> ListRuleSnapshotsFluentBuilder

Constructs a fluent builder for the ListRuleSnapshots operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_rules(&self) -> ListRulesFluentBuilder

Constructs a fluent builder for the ListRules operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_scope_snapshots(&self) -> ListScopeSnapshotsFluentBuilder

Constructs a fluent builder for the ListScopeSnapshots operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_scopes(&self) -> ListScopesFluentBuilder

Constructs a fluent builder for the ListScopes operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_tags_for_resource(&self) -> ListTagsForResourceFluentBuilder

Constructs a fluent builder for the ListTagsForResource operation.

Source

impl Client

pub fn list_template_snapshots(&self) -> ListTemplateSnapshotsFluentBuilder

Constructs a fluent builder for the ListTemplateSnapshots operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_templates(&self) -> ListTemplatesFluentBuilder

Constructs a fluent builder for the ListTemplates operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn put_admin_account(&self) -> PutAdminAccountFluentBuilder

Constructs a fluent builder for the PutAdminAccount operation.

Source

impl Client

pub fn tag_resource(&self) -> TagResourceFluentBuilder

Constructs a fluent builder for the TagResource operation.

Source

impl Client

pub fn untag_resource(&self) -> UntagResourceFluentBuilder

Constructs a fluent builder for the UntagResource operation.

Source

impl Client

pub fn update_deployment(&self) -> UpdateDeploymentFluentBuilder

Constructs a fluent builder for the UpdateDeployment operation.

Source

impl Client

pub fn update_policy(&self) -> UpdatePolicyFluentBuilder

Constructs a fluent builder for the UpdatePolicy operation.

Source

impl Client

pub fn update_rule(&self) -> UpdateRuleFluentBuilder

Constructs a fluent builder for the UpdateRule operation.

Source

impl Client

pub fn update_scope(&self) -> UpdateScopeFluentBuilder

Constructs a fluent builder for the UpdateScope operation.

Source

impl Client

pub fn update_template(&self) -> UpdateTemplateFluentBuilder

Constructs a fluent builder for the UpdateTemplate operation.

Source

impl Client

pub fn from_conf(conf: Config) -> Self

Creates a new client from the service Config.

Panics

This method will panic in the following cases:

  • Retries or timeouts are enabled without a sleep_impl configured.
  • Identity caching is enabled without a sleep_impl and time_source configured.
  • No behavior_version is provided.

The panic message for each of these will have instructions on how to resolve them.

pub fn config(&self) -> &Config

Returns the client’s configuration.

Source

impl Client

pub fn new(sdk_config: &SdkConfig) -> Self

Creates a new client from an SDK Config.

Panics
  • This method will panic if the sdk_config is missing an async sleep implementation. If you experience this panic, set the sleep_impl on the Config passed into this function to fix it.
  • This method will panic if the sdk_config is missing an HTTP connector. If you experience this panic, set the http_connector on the Config passed into this function to fix it.
  • This method will panic if no BehaviorVersion is provided. If you experience this panic, set behavior_version on the Config or enable the behavior-version-latest Cargo feature.