#[non_exhaustive]pub struct CreateRuleSnapshotOutputBuilder { /* private fields */ }Expand description
A builder for CreateRuleSnapshotOutput.
Implementations
Sourceimpl CreateRuleSnapshotOutputBuilder
impl CreateRuleSnapshotOutputBuilder
Sourcepub fn rule_id(self, input: impl Into<String>) -> Self
pub fn rule_id(self, input: impl Into<String>) -> Self
The service-generated id of the rule.
This field is required.Sourcepub fn set_rule_id(self, input: Option<String>) -> Self
pub fn set_rule_id(self, input: Option<String>) -> Self
The service-generated id of the rule.
Sourcepub fn get_rule_id(&self) -> &Option<String>
pub fn get_rule_id(&self) -> &Option<String>
The service-generated id of the rule.
Sourcepub fn rule_arn(self, input: impl Into<String>) -> Self
pub fn rule_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the rule.
This field is required.Sourcepub fn set_rule_arn(self, input: Option<String>) -> Self
pub fn set_rule_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the rule.
Sourcepub fn get_rule_arn(&self) -> &Option<String>
pub fn get_rule_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the rule.
Sourcepub fn rule_name(self, input: impl Into<String>) -> Self
pub fn rule_name(self, input: impl Into<String>) -> Self
The name of the rule.
This field is required.Sourcepub fn set_rule_name(self, input: Option<String>) -> Self
pub fn set_rule_name(self, input: Option<String>) -> Self
The name of the rule.
Sourcepub fn get_rule_name(&self) -> &Option<String>
pub fn get_rule_name(&self) -> &Option<String>
The name of the rule.
Sourcepub fn firewall_type(self, input: RuleFirewallType) -> Self
pub fn firewall_type(self, input: RuleFirewallType) -> Self
The firewall type associated with the resource.
This field is required.Sourcepub fn set_firewall_type(self, input: Option<RuleFirewallType>) -> Self
pub fn set_firewall_type(self, input: Option<RuleFirewallType>) -> Self
The firewall type associated with the resource.
Sourcepub fn get_firewall_type(&self) -> &Option<RuleFirewallType>
pub fn get_firewall_type(&self) -> &Option<RuleFirewallType>
The firewall type associated with the resource.
Sourcepub fn rule_type(self, input: RuleType) -> Self
pub fn rule_type(self, input: RuleType) -> Self
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn set_rule_type(self, input: Option<RuleType>) -> Self
pub fn set_rule_type(self, input: Option<RuleType>) -> Self
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn get_rule_type(&self) -> &Option<RuleType>
pub fn get_rule_type(&self) -> &Option<RuleType>
The type of the rule. CONFIGURATION rules contain firewall settings, and INSPECTION rules contain rule groups.
Sourcepub fn rule_description(self, input: impl Into<String>) -> Self
pub fn rule_description(self, input: impl Into<String>) -> Self
A description of the rule.
Sourcepub fn set_rule_description(self, input: Option<String>) -> Self
pub fn set_rule_description(self, input: Option<String>) -> Self
A description of the rule.
Sourcepub fn get_rule_description(&self) -> &Option<String>
pub fn get_rule_description(&self) -> &Option<String>
A description of the rule.
Sourcepub fn configuration(self, input: Document) -> Self
pub fn configuration(self, input: Document) -> Self
The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type.
This field is required.Sourcepub fn set_configuration(self, input: Option<Document>) -> Self
pub fn set_configuration(self, input: Option<Document>) -> Self
The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type.
Sourcepub fn get_configuration(&self) -> &Option<Document>
pub fn get_configuration(&self) -> &Option<Document>
The firewall configuration for the rule, as a JSON document. The structure depends on the rule's firewall type and rule type.
Sourcepub fn status(self, input: EntityStatus) -> Self
pub fn status(self, input: EntityStatus) -> Self
The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
Sourcepub fn set_status(self, input: Option<EntityStatus>) -> Self
pub fn set_status(self, input: Option<EntityStatus>) -> Self
The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
Sourcepub fn get_status(&self) -> &Option<EntityStatus>
pub fn get_status(&self) -> &Option<EntityStatus>
The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
Sourcepub fn version(self, input: impl Into<String>) -> Self
pub fn version(self, input: impl Into<String>) -> Self
The version of the resource.
This field is required.Sourcepub fn set_version(self, input: Option<String>) -> Self
pub fn set_version(self, input: Option<String>) -> Self
The version of the resource.
Sourcepub fn get_version(&self) -> &Option<String>
pub fn get_version(&self) -> &Option<String>
The version of the resource.
Sourcepub fn update_token(self, input: impl Into<String>) -> Self
pub fn update_token(self, input: impl Into<String>) -> Self
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn set_update_token(self, input: Option<String>) -> Self
pub fn set_update_token(self, input: Option<String>) -> Self
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn get_update_token(&self) -> &Option<String>
pub fn get_update_token(&self) -> &Option<String>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn is_snapshot(self, input: bool) -> Self
pub fn is_snapshot(self, input: bool) -> Self
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn set_is_snapshot(self, input: Option<bool>) -> Self
pub fn set_is_snapshot(self, input: Option<bool>) -> Self
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn get_is_snapshot(&self) -> &Option<bool>
pub fn get_is_snapshot(&self) -> &Option<bool>
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn has_published_version(self, input: bool) -> Self
pub fn has_published_version(self, input: bool) -> Self
Specifies whether a published version of the resource exists.
Sourcepub fn set_has_published_version(self, input: Option<bool>) -> Self
pub fn set_has_published_version(self, input: Option<bool>) -> Self
Specifies whether a published version of the resource exists.
Sourcepub fn get_has_published_version(&self) -> &Option<bool>
pub fn get_has_published_version(&self) -> &Option<bool>
Specifies whether a published version of the resource exists.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The time when the snapshot was created.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The time when the snapshot was created.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The time when the snapshot was created.
Sourcepub fn build(self) -> Result<CreateRuleSnapshotOutput, BuildError>
pub fn build(self) -> Result<CreateRuleSnapshotOutput, BuildError>
Consumes the builder and constructs a CreateRuleSnapshotOutput.
This method will fail if any of the following fields are not set: