#[non_exhaustive]pub struct GetPolicyOutput {Show 14 fields
pub policy_id: String,
pub policy_arn: String,
pub policy_name: String,
pub policy_description: Option<String>,
pub status: EntityStatus,
pub priority: i32,
pub associated_template_and_rule_list: Vec<AssociatedTemplateOrRule>,
pub version: String,
pub update_token: Option<String>,
pub is_snapshot: Option<bool>,
pub has_published_version: Option<bool>,
pub firewall_type: PolicyFirewallType,
pub policy_configuration: Option<PolicyConfiguration>,
pub updated_at: Option<DateTime>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.policy_id: StringThe service-generated id of the policy.
policy_arn: StringThe Amazon Resource Name (ARN) of the policy.
policy_name: StringThe name of the policy.
policy_description: Option<String>A description of the policy.
status: EntityStatusThe current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
priority: i32The priority of the resource. A lower number indicates a higher priority.
associated_template_and_rule_list: Vec<AssociatedTemplateOrRule>The templates and rules associated with the policy. For AWS WAF policies, this list contains 1 to 100 templates or rules, of which at most 2 can be templates. For AWS Shield Advanced policies, this list is empty.
version: StringThe version of the resource.
update_token: Option<String>A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
is_snapshot: Option<bool>Specifies whether the resource is a snapshot of a published version.
has_published_version: Option<bool>Specifies whether a published version of the resource exists.
firewall_type: PolicyFirewallTypeThe firewall type associated with the resource.
policy_configuration: Option<PolicyConfiguration>The configuration settings that control the policy's behavior, including remediation and firewall-type-specific settings.
updated_at: Option<DateTime>The time when the resource was last updated.
Implementations
Sourceimpl GetPolicyOutput
impl GetPolicyOutput
Sourcepub fn policy_arn(&self) -> &str
pub fn policy_arn(&self) -> &str
The Amazon Resource Name (ARN) of the policy.
Sourcepub fn policy_name(&self) -> &str
pub fn policy_name(&self) -> &str
The name of the policy.
Sourcepub fn policy_description(&self) -> Option<&str>
pub fn policy_description(&self) -> Option<&str>
A description of the policy.
Sourcepub fn status(&self) -> &EntityStatus
pub fn status(&self) -> &EntityStatus
The current status of the resource: DRAFT (unpublished, editable) or ACTIVE (published, in use).
Sourcepub fn priority(&self) -> i32
pub fn priority(&self) -> i32
The priority of the resource. A lower number indicates a higher priority.
Sourcepub fn associated_template_and_rule_list(&self) -> &[AssociatedTemplateOrRule]
pub fn associated_template_and_rule_list(&self) -> &[AssociatedTemplateOrRule]
The templates and rules associated with the policy. For AWS WAF policies, this list contains 1 to 100 templates or rules, of which at most 2 can be templates. For AWS Shield Advanced policies, this list is empty.
Sourcepub fn update_token(&self) -> Option<&str>
pub fn update_token(&self) -> Option<&str>
A token used for optimistic concurrency control. Each read and write returns an updateToken. Provide the most recent value on your next update to detect and prevent conflicting concurrent modifications.
Sourcepub fn is_snapshot(&self) -> Option<bool>
pub fn is_snapshot(&self) -> Option<bool>
Specifies whether the resource is a snapshot of a published version.
Sourcepub fn has_published_version(&self) -> Option<bool>
pub fn has_published_version(&self) -> Option<bool>
Specifies whether a published version of the resource exists.
Sourcepub fn firewall_type(&self) -> &PolicyFirewallType
pub fn firewall_type(&self) -> &PolicyFirewallType
The firewall type associated with the resource.
Sourcepub fn policy_configuration(&self) -> Option<&PolicyConfiguration>
pub fn policy_configuration(&self) -> Option<&PolicyConfiguration>
The configuration settings that control the policy's behavior, including remediation and firewall-type-specific settings.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The time when the resource was last updated.
Sourceimpl GetPolicyOutput
impl GetPolicyOutput
Sourcepub fn builder() -> GetPolicyOutputBuilder
pub fn builder() -> GetPolicyOutputBuilder
Creates a new builder-style object to manufacture GetPolicyOutput.